from a10sdk.common.A10BaseClass import A10BaseClass


class EntryCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param distance: {"minimum": 1, "type": "number", "maximum": 255, "format": "number"}
    :param protocol: {"enum": ["any", "static", "dynamic"], "type": "string", "description": "any: \"any\"; static: \"static\"; dynamic: \"dynamic\"; ", "format": "enum"}
    :param weight: {"minimum": 1, "type": "number", "maximum": 255, "format": "number"}
    :param dst: {"type": "string", "format": "ipv4-address"}
    :param mask: {"type": "string", "format": "ipv4-netmask"}
    :param gateway: {"type": "string", "format": "ipv4-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "entry-cfg"
        self.DeviceProxy = ""
        self.distance = ""
        self.protocol = ""
        self.weight = ""
        self.dst = ""
        self.mask = ""
        self.gateway = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class List(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param entry_cfg: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"distance": {"minimum": 1, "type": "number", "maximum": 255, "format": "number"}, "protocol": {"enum": ["any", "static", "dynamic"], "type": "string", "description": "any: \"any\"; static: \"static\"; dynamic: \"dynamic\"; ", "format": "enum"}, "weight": {"minimum": 1, "type": "number", "maximum": 255, "format": "number"}, "dst": {"type": "string", "format": "ipv4-address"}, "mask": {"type": "string", "format": "ipv4-netmask"}, "optional": true, "gateway": {"type": "string", "format": "ipv4-address"}}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "list"
        self.DeviceProxy = ""
        self.entry_cfg = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class ListEntry2(A10BaseClass):
    
    """Class Description::
    Unit test CM list where entry fields are mandatory for one with construct.

    Class list-entry-2 supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cm-ut/list-entry-2`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "list-entry-2"
        self.a10_url="/axapi/v3/cm-ut/list-entry-2"
        self.DeviceProxy = ""
        self.A10WW_list = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class VirtualServer(A10BaseClass):
    
    """Class Description::
    Create a Virtual Server.

    Class virtual-server supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param port_list: {"minItems": 1, "items": {"type": "port"}, "uniqueItems": true, "array": [{"required": ["port-number", "protocol"], "properties": {"reset-on-server-selection-fail": {"default": 0, "optional": true, "type": "number", "description": "Send client reset when server selection fails", "format": "flag"}, "ha-conn-mirror": {"default": 0, "optional": true, "type": "number", "description": "Enable for HA Conn sync", "format": "flag"}, "template-ftp": {"description": "FTP port template (Ftp template name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 31, "type": "string", "$ref": "/axapi/v3/slb/template/ftp"}, "protocol": {"optional": false, "enum": ["tcp", "udp", "others", "diameter", "dns-tcp", "dns-udp", "fast-http", "fix", "ftp", "ftp-proxy", "http", "https", "mlb", "mms", "mysql", "mssql", "radius", "rtsp", "sip", "sip-tcp", "sips", "smpp-tcp", "spdy", "spdys", "smtp", "ssl-proxy", "tcp-proxy", "tftp"], "type": "string", "description": "'tcp': TCP LB service; 'udp': UDP Port; 'others': for no tcp/udp protocol, do IP load balancing; 'diameter': diameter port; 'dns-tcp': DNS service over TCP; 'dns-udp': DNS service over UDP; 'fast-http': Fast HTTP Port; 'fix': FIX Port; 'ftp': File Transfer Protocol Port; 'ftp-proxy': ftp proxy port; 'http': HTTP Port; 'https': HTTPS port; 'mlb': Message based load balancing; 'mms': Microsoft Multimedia Service Port; 'mysql': mssql port; 'mssql': mssql; 'radius': Radius Port; 'rtsp': Real Time Streaming Protocol Port; 'sip': Session initiation protocol over UDP; 'sip-tcp': Session initiation protocol over TCP; 'sips': Session initiation protocol over TLS; 'smpp-tcp': SMPP service over TCP; 'spdy': spdy port; 'spdys': spdys port; 'smtp': SMTP Port; 'ssl-proxy': Generic SSL proxy; 'tcp-proxy': Generic TCP proxy; 'tftp': TFTP Port; ", "format": "enum"}, "force-routing-mode": {"default": 0, "optional": true, "type": "number", "description": "Force routing mode", "format": "flag"}, "waf-template": {"description": "WAF template (WAF Template Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/waf/template"}, "l7-hardware-assist": {"description": "FPGA assist L7 packet parsing", "format": "flag", "default": 0, "type": "number", "optional": true, "plat-neg-list": ["non-fpga", "soft-ax"]}, "template-persist-ssl-sid": {"description": "SSL session ID persistence (Source IP Persistence Config name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string", "$ref": "/axapi/v3/slb/template/persist/ssl-sid"}, "no-auto-up-on-aflex": {"default": 0, "optional": true, "type": "number", "description": "Don't automatically mark vport up when aFleX is bound", "format": "flag"}, "template-dns": {"description": "DNS template (DNS template name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/dns"}, "template-http-policy": {"description": "http-policy template (http-policy template name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/http-policy"}, "gslb-enable": {"default": 0, "optional": true, "type": "number", "description": "Enable Global Server Load Balancing", "format": "flag"}, "template-policy": {"description": "Policy Template (Policy template name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/policy"}, "use-alternate-port": {"default": 0, "optional": true, "type": "number", "description": "Use alternate virtual port", "format": "flag"}, "ipinip": {"default": 0, "optional": true, "type": "number", "description": "Enable IP in IP", "format": "flag"}, "acl-name-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"acl-name": {"description": "Apply an access list name (Named Access List)", "format": "string", "minLength": 1, "maxLength": 16, "type": "string", "$ref": "/axapi/v3/ip/access-list"}, "acl-name-src-nat-pool": {"description": "Policy based Source NAT (NAT Pool or Pool Group)", "format": "string", "minLength": 1, "maxLength": 128, "type": "string", "$ref": "/axapi/v3/ip/nat/pool"}, "optional": true, "acl-name-seq-num": {"description": "Specify ACL precedence (sequence-number)", "minimum": 1, "type": "number", "maximum": 32, "format": "number"}}}]}, "stats-data-action": {"description": "'stats-data-enable': Enable statistical data collection for virtual port; 'stats-data-disable': Disable statistical data collection for virtual port; ", "format": "enum", "default": "stats-data-enable", "type": "string", "enum": ["stats-data-enable", "stats-data-disable"], "optional": true}, "template-persist-destination-ip": {"description": "Destination IP persistence (Destination IP persistence template name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string", "$ref": "/axapi/v3/slb/template/persist/destination-ip"}, "template-tcp-proxy-server": {"description": "TCP Proxy Config Server (TCP Proxy Config name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/tcp-proxy"}, "template-sip": {"description": "SIP template", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/sip"}, "template-virtual-port": {"description": "Virtual port template (Virtual port template name)", "format": "string", "default": "default", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/virtual-port"}, "conn-limit": {"description": "Connection Limit", "format": "number", "default": 8000000, "optional": true, "maximum": 8000000, "minimum": 1, "type": "number"}, "precedence": {"default": 0, "optional": true, "type": "number", "description": "Set auto NAT pool as higher precedence for source NAT", "format": "flag"}, "template-client-ssl": {"description": "Client SSL Template (Client SSL Config Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/client-ssl"}, "template-persist-cookie": {"description": "Cookie persistence (Cookie persistence template name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string", "$ref": "/axapi/v3/slb/template/persist/cookie"}, "template-tcp": {"description": "L4 TCP Template (TCP Config Name)", "format": "string", "default": "default", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/tcp"}, "template-tcp-proxy-client": {"description": "TCP Proxy Config Client (TCP Proxy Config name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/tcp-proxy"}, "template-connection-reuse": {"description": "Connection Reuse Template (Connection Reuse Template Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string", "$ref": "/axapi/v3/slb/template/connection-reuse"}, "service-group": {"description": "Bind a Service Group to this Virtual Server (Service Group Name)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 128, "type": "string", "$ref": "/axapi/v3/slb/service-group"}, "pool": {"description": "Specify NAT pool or pool group", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string", "$ref": "/axapi/v3/ip/nat/pool"}, "persist-type": {"optional": true, "enum": ["src-dst-ip-swap-persist", "use-src-ip-for-dst-persist", "use-dst-ip-for-src-persist"], "type": "string", "description": "'src-dst-ip-swap-persist': Create persist session after source IP and destination IP swap; 'use-src-ip-for-dst-persist': Use the source IP to create a destination persist session; 'use-dst-ip-for-src-persist': Use the destination IP to create source IP persist session; ", "format": "enum"}, "template-fix": {"description": "FIX template (FIX Template Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/fix"}, "snat-on-vip": {"default": 0, "optional": true, "type": "number", "description": "Enable source NAT traffic against VIP", "format": "flag"}, "bucket-count": {"optional": true, "minimum": 1, "type": "number", "maximum": 256, "format": "number"}, "use-default-if-no-server": {"default": 0, "optional": true, "type": "number", "description": "Use default forwarding if server selection failed", "format": "flag"}, "syn-cookie": {"default": 0, "optional": true, "type": "number", "description": "Enable syn-cookie", "format": "flag"}, "when-down": {"default": 0, "optional": true, "type": "number", "description": "Use alternate virtual port when down", "format": "flag"}, "template-udp": {"description": "L4 UDP Template (UDP Config Name)", "format": "string", "default": "default", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/udp"}, "aflex-scripts": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"aflex": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Bind aFleX Script to the Virtual Port (aFleX Script Name)", "format": "string"}, "optional": true}}]}, "acl-id-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"acl-id-seq-num": {"description": "Specify ACL precedence (sequence-number)", "minimum": 1, "type": "number", "maximum": 32, "format": "number"}, "acl-id": {"description": "ACL id VPORT", "format": "number", "maximum": 199, "minimum": 1, "type": "number", "$ref": "/axapi/v3/access-list/standard"}, "optional": true, "acl-id-src-nat-pool": {"description": "Policy based Source NAT (NAT Pool or Pool Group)", "format": "string", "minLength": 1, "maxLength": 128, "type": "string", "$ref": "/axapi/v3/ip/nat/pool"}}}]}, "alternate-port": {"description": "Alternate Virtual Port", "format": "flag", "default": 0, "optional": true, "modify-not-allowed": 1, "not": "range", "type": "number"}, "auto": {"default": 0, "optional": true, "type": "number", "description": "Configure auto NAT for the vport", "format": "flag"}, "view": {"description": "Specify a GSLB View (ID)", "format": "number", "type": "number", "maximum": 31, "minimum": 1, "optional": true}, "alternate-port-number": {"description": "Virtual Port", "format": "number", "type": "number", "maximum": 65534, "minimum": 0, "optional": true}, "port-number": {"description": "Port", "format": "number", "type": "number", "maximum": 65534, "minimum": 0, "optional": false}, "device-group": {"optional": true, "minimum": 1, "type": "number", "maximum": 64, "format": "number"}, "use-rcv-hop-for-resp": {"default": 0, "optional": true, "type": "number", "description": "Use receive hop for response to client", "format": "flag"}, "no-dest-nat": {"default": 0, "optional": true, "type": "number", "description": "Disable destination NAT", "format": "flag"}, "template-external-service": {"description": "External service template (external-service template name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/external-service"}, "template-cache": {"description": "RAM caching template (Cache Template Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/cache"}, "extended-stats": {"default": 0, "optional": true, "type": "number", "description": "Enable extended statistics on virtual port", "format": "flag"}, "expand": {"default": 0, "optional": true, "type": "number", "description": "expand syn-cookie with timestamp and wscale", "format": "flag"}, "reset": {"default": 0, "optional": true, "type": "number", "description": "Send client reset when connection number over limit", "format": "flag"}, "req-fail": {"default": 0, "optional": true, "type": "number", "description": "Use alternate virtual port when L7 request fail", "format": "flag"}, "skip-rev-hash": {"default": 0, "optional": true, "type": "number", "description": "Skip rev tuple hash insertion", "format": "flag"}, "name": {"description": "SLB Virtual Service Name", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 127, "type": "string"}, "template-dblb": {"description": "DBLB Template (DBLB template name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/dblb"}, "port-translation": {"default": 0, "optional": true, "type": "number", "description": "Enable port translation under no-dest-nat", "format": "flag"}, "template-smpp": {"description": "SMPP template", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/smpp"}, "clientip-sticky-nat": {"default": 0, "optional": true, "type": "number", "description": "Prefer to use same source NAT address for a client", "format": "flag"}, "template-persist-source-ip": {"description": "Source IP persistence (Source IP persistence template name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string", "$ref": "/axapi/v3/slb/template/persist/source-ip"}, "serv-sel-fail": {"default": 0, "optional": true, "type": "number", "description": "Use alternate virtual port when server selection failure", "format": "flag"}, "template-diameter": {"description": "Diameter Template (diameter template name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/diameter"}, "range": {"description": "Virtual Port range (Virtual Port range value)", "format": "number", "default": 0, "optional": true, "maximum": 254, "minimum": 0, "modify-not-allowed": 1, "not": "alternate-port", "type": "number"}, "when-down-protocol2": {"default": 0, "optional": true, "type": "number", "description": "Use alternate virtual port when down", "format": "flag"}, "def-selection-if-pref-failed": {"description": "'def-selection-if-pref-failed': Use default server selection method if prefer method failed; 'def-selection-if-pref-failed-disable': Stop using default server selection method if prefer method failed; ", "format": "enum", "default": "def-selection-if-pref-failed", "type": "string", "enum": ["def-selection-if-pref-failed", "def-selection-if-pref-failed-disable"], "optional": true}, "template-tcp-proxy": {"description": "TCP Proxy Template Name", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/tcp-proxy"}, "template-smtp": {"description": "SMTP Template (SMTP Config Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/smtp"}, "auth-cfg": {"type": "object", "properties": {"aaa-policy": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify AAA policy name to bind to the virtual port", "format": "string"}}}, "action": {"description": "'enable': Enable; 'disable': Disable; ", "format": "enum", "default": "enable", "type": "string", "enum": ["enable", "disable"], "optional": true}, "template-http": {"description": "HTTP Template (HTTP Config Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/http"}, "no-logging": {"default": 0, "optional": true, "type": "number", "description": "Do not log connection over limit event", "format": "flag"}, "template-server-ssl": {"description": "Server Side SSL Template (Server SSL Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/server-ssl"}, "alt-protocol2": {"optional": true, "enum": ["tcp"], "type": "string", "description": "'tcp': TCP LB service; ", "format": "enum"}, "alt-protocol1": {"optional": true, "enum": ["http"], "type": "string", "description": "'http': HTTP Port; ", "format": "enum"}, "message-switching": {"default": 0, "optional": true, "type": "number", "description": "Message switching", "format": "flag"}}}], "type": "array", "$ref": "/axapi/v3/slb/virtual-server/{name}/port/{port-number}+{protocol}"}
    :param stats_data_action: {"description": "'stats-data-enable': Enable statistical data collection for virtual server; 'stats-data-disable': Disable statistical data collection for virtual server; ", "format": "enum", "default": "stats-data-enable", "type": "string", "enum": ["stats-data-enable", "stats-data-disable"], "optional": true}
    :param acl_name: {"description": "Access List name (IPv4 Access List Name)", "format": "string", "minLength": 1, "modify-not-allowed": 1, "optional": true, "maxLength": 16, "type": "string", "$ref": "/axapi/v3/ip/access-list"}
    :param enable_disable_action: {"description": "'enable': Enable Virtual Server (default); 'disable': Disable Virtual Server; 'disable-when-all-ports-down': Disable Virtual Server when all member ports are down; 'disable-when-any-port-down': Disable Virtual Server when any member port is down; ", "format": "enum", "default": "enable", "type": "string", "enum": ["enable", "disable", "disable-when-all-ports-down", "disable-when-any-port-down"], "optional": true}
    :param ip_address: {"description": "IP Address", "format": "ipv4-address", "optional": true, "not-list": ["ipv6-address", "use-if-ip"], "modify-not-allowed": 1, "type": "string"}
    :param use_if_ip: {"description": "Use Interface IP", "format": "flag", "default": 0, "optional": true, "plat-pos-list": ["soft-ax"], "not-list": ["ipv6-address", "ip-address"], "type": "number"}
    :param vrid: {"description": "Join a vrrp group (Specify ha VRRP-A vrid)", "format": "number", "type": "number", "maximum": 31, "minimum": 1, "optional": true}
    :param template_virtual_server: {"description": "Virtual server template name", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/virtual-server"}
    :param policy: {"default": 0, "optional": true, "type": "number", "description": "Policy template", "format": "flag"}
    :param arp_disable: {"default": 0, "optional": true, "type": "number", "description": "Disable Respond to Virtual Server ARP request", "format": "flag"}
    :param description: {"description": "Create a description for VIP", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param redistribution_flagged: {"default": 0, "optional": true, "type": "number", "description": "Flag VIP for special redistribution handling", "format": "flag"}
    :param netmask: {"optional": true, "modify-not-allowed": 1, "type": "string", "description": "IP subnet mask", "format": "ipv4-netmask-brief"}
    :param acl_id: {"description": "acl id", "format": "number", "optional": true, "maximum": 199, "minimum": 1, "modify-not-allowed": 1, "type": "number", "$ref": "/axapi/v3/access-list/standard"}
    :param ipv6_acl: {"description": "ipv6 acl name", "format": "string", "minLength": 1, "modify-not-allowed": 1, "optional": true, "maxLength": 31, "type": "string", "$ref": "/axapi/v3/ipv6/access-list"}
    :param virtual_server: {"default": 0, "optional": true, "type": "number", "description": "Virtual server template", "format": "flag"}
    :param template_logging: {"description": "NAT Logging template name", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/ip/nat/template/logging"}
    :param extended_stats: {"default": 0, "optional": true, "type": "number", "description": "Enable extended statistics on virtual server", "format": "flag"}
    :param logging: {"default": 0, "optional": true, "type": "number", "description": "NAT Logging template", "format": "flag"}
    :param name: {"description": "SLB Virtual Server Name", "format": "string-rlx", "minLength": 1, "optional": false, "maxLength": 127, "type": "string"}
    :param template_policy: {"description": "Policy template name", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/policy"}
    :param ipv6_address: {"description": "IPV6 address", "format": "ipv6-address", "optional": true, "not-list": ["ip-address", "use-if-ip"], "modify-not-allowed": 1, "type": "string"}
    :param ethernet: {"optional": true, "plat-pos-list": ["soft-ax"], "type": "number", "description": "Ethernet interface", "format": "interface"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/virtual-server/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "virtual-server"
        self.a10_url="/axapi/v3/slb/virtual-server/{name}"
        self.DeviceProxy = ""
        self.port_list = []
        self.stats_data_action = ""
        self.acl_name = ""
        self.enable_disable_action = ""
        self.ip_address = ""
        self.use_if_ip = ""
        self.vrid = ""
        self.template_virtual_server = ""
        self.policy = ""
        self.arp_disable = ""
        self.description = ""
        self.redistribution_flagged = ""
        self.netmask = ""
        self.acl_id = ""
        self.ipv6_acl = ""
        self.virtual_server = ""
        self.template_logging = ""
        self.extended_stats = ""
        self.logging = ""
        self.name = ""
        self.template_policy = ""
        self.ipv6_address = ""
        self.ethernet = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





__author__ = 'mthompson'
import base64
import httplib
import json
import mimetypes
import random
import string
import urllib
import urlparse


class DeviceProxy():
    def __init__(self, host, port, username, password, use_https=True, keep_alive=False):
        self.username = username
        self.password = password
        self.host = host
        self.port = port
        #self.lastPayload = "No Data"
        #self.lastResult = "No Data"
        self.keep_alive = keep_alive
        self.use_https = use_https
        self.logon()

    def get_connection(self):
        if self.use_https:
            return httplib.HTTPSConnection(self.host, port=self.port)
        else:
            return httplib.HTTPConnection(self.host, port=self.port)

    def logon(self):
        headers = {'Content-type': 'application/json'}
        conn = self.get_connection()
        conn.request("POST", "/axapi/v3/auth",
                     json.dumps({'credentials': {"username": self.username, "password": self.password}}), headers)
        self.password = ''
        try:
            response = json.loads(conn.getresponse().read())
            if "authresponse" in response:
                self.session_id = str(response['authresponse']['signature'])
                self.headers = {'Content-type': 'application/json', 'Authorization': "A10 %s" % self.session_id}
            else:
                self.session_id = "AUTHENTICATION FAILED"
                self.headers = {'Content-type': 'application/json', 'Authorization': "A10 %s" % self.session_id}

        except:
            return None

    def logoff(self):
        logoff_uri = "/axapi/v3/logoff"
        conn = self.get_connection()
        conn.request("POST", logoff_uri, "", self.headers)
        response = conn.getresponse().read()
        return response

    def request_handler(self, method, obj, response):
        response_payload = response.read()
        obj.__setattr__("DEBUG_Response", response_payload)
        obj.__setattr__("_HTTP_RESPONSE", response)
        if response.status == 401:
            if self.keep_alive:
                self.logon()
                if method == "GET":
                    return self.GET(obj)
                elif method == "GET_MP":
                    return self.multi_part_get(obj)
                elif method == "MPP":
                    return self.post_multipart(obj)
                elif method == "FD":
                    return self.file_delete(obj)
                elif method == "POST":
                    return self.POST(obj)
                elif method == "PUT":
                    return self.PUT(obj)
                elif method == "DELETE":
                    return self.DELETE(obj)
            else:
                return "Session Timeout"

        if len(response_payload) == 0:
            return None

        return response_payload

    def GET(self, obj, query_params=None):
        # Replace the a10_url with just the base path, stripping out any previous querystring
        parse_result = urlparse.urlparse(obj.a10_url)
        obj.a10_url = parse_result.path
        obj.a10_url = self.url_encoder(obj.a10_url)
        if query_params:
            obj.a10_url += '?' + urlparse.unquote(urllib.urlencode(query_params))

        print "URL:", obj.a10_url
        conn = self.get_connection()
        conn.request("GET", obj.a10_url, "", self.headers)
        response = conn.getresponse()
        conn.close()
        obj.__setattr__("DEBUG_CONNECTION", conn.__dict__)
        obj.__setattr__("DEBUG_Payload", "")
        obj.__setattr__("DEBUG_Response", response)
        obj.__setattr__("DEBUG_URL", obj.a10_url)
        obj.__setattr__("DEBUG_headers", self.headers)
        return self.request_handler("GET", obj, response)


    # TODO: Due to Bug 175975, add zero_length kwarg to optionally send zero-length POST. Remove code once bug resolved
    def POST(self, obj, zero_length=False):
        obj.a10_url = self.url_encoder(obj.a10_url)
        conn = self.get_connection()

        if zero_length:
            payload = None
        else:
            payload = obj.__json__(obj)
            if payload:
                payload = json.dumps(payload)

        conn.request("POST", self.url_encoder(obj.a10_url), payload, self.headers)
        response = conn.getresponse()
        obj.__setattr__("DEBUG_CONNECTION", conn.__dict__)
        conn.close()
        obj.__setattr__("DEBUG_Payload", payload)
        obj.__setattr__("DEBUG_Response", response)
        obj.__setattr__("DEBUG_URL", obj.a10_url)
        obj.__setattr__("DEBUG_headers", self.headers)
        return self.request_handler("POST", obj, response)

    def PUT(self, obj, payload_empty_string=False):
        obj.a10_url = self.url_encoder(obj.a10_url)
        conn = self.get_connection()
        if payload_empty_string:
            payload = ''
        else:
            json_output = obj.__json__(obj)
            if json_output:
                payload = json.dumps(obj.__json__(obj))
            else:
                payload = ''
        conn.request("PUT", self.url_encoder(obj.a10_url), payload, self.headers)
        response = conn.getresponse()
        conn.close()
        obj.__setattr__("DEBUG_CONNECTION", conn.__dict__)
        obj.__setattr__("DEBUG_Payload", payload)
        obj.__setattr__("DEBUG_Response", response)
        obj.__setattr__("DEBUG_URL", obj.a10_url)
        obj.__setattr__("DEBUG_headers", self.headers)
        return self.request_handler("PUT", obj, response)

    def POST_ALL(self, caller, obj_list):
        formatted_key = caller.b_key
        json_key = formatted_key + '-list'
        json_data = []
        for obj in obj_list:
            if obj.__json__(obj).get(formatted_key):
                json_data.append(obj.__json__(obj).get(formatted_key))
        json_packet = {}
        json_packet[json_key] = json_data
        payload = json.dumps(json_packet)
        conn = self.get_connection()
        conn.request("POST", self.url_encoder(caller.a10_url), payload, self.headers)
        response = conn.getresponse()
        conn.close()
        caller.__setattr__("DEBUG_CONNECTION", conn.__dict__)
        caller.__setattr__("DEBUG_Payload", payload)
        caller.__setattr__("DEBUG_Response", response)
        caller.__setattr__("DEBUG_URL", caller.a10_url)
        caller.__setattr__("DEBUG_headers", self.headers)
        return self.request_handler("POST", caller, response)

    def PUT_ALL(self, caller, obj_list):
        formatted_key = caller.b_key
        json_key = formatted_key + '-list'
        json_data = []
        for obj in obj_list:
            if obj.__json__(obj).get(formatted_key):
                json_data.append(obj.__json__(obj).get(formatted_key))
        json_packet = {}
        json_packet[json_key] = json_data
        payload = json.dumps(json_packet)
        conn = self.get_connection()
        conn.request("PUT", self.url_encoder(caller.a10_url), payload, self.headers)
        response = conn.getresponse()
        conn.close()
        caller.__setattr__("DEBUG_CONNECTION", conn.__dict__)
        caller.__setattr__("DEBUG_Payload", payload)
        caller.__setattr__("DEBUG_Response", response)
        caller.__setattr__("DEBUG_URL", caller.a10_url)
        caller.__setattr__("DEBUG_headers", self.headers)
        return self.request_handler("PUT", caller, response)


    def DELETE(self, obj):
        obj.a10_url = self.url_encoder(obj.a10_url)
        conn = self.get_connection()
        payload = None
        conn.request("DELETE", self.url_encoder(obj.a10_url), "", self.headers)
        response = conn.getresponse()
        conn.close()
        obj.__setattr__("DEBUG_CONNECTION", conn.__dict__)
        obj.__setattr__("DEBUG_Payload", "")
        obj.__setattr__("DEBUG_Response", response)
        obj.__setattr__("DEBUG_URL", obj.a10_url)
        obj.__setattr__("DEBUG_headers", self.headers)
        return self.request_handler("DELETE", obj, response)


    def url_encoder(self, url):
        url = url.replace(" ", "%20")
        return url


    def post_multipart(self, obj):
        """
        Post fields and files to an http host as multipart/form-data.
        fields is a sequence of (name, value) elements for regular form fields.
        files is a sequence of (name, filename, value) elements for data to be uploaded as files
        Return the server's response page.
        """
        content_type, body = self.encode_multipart_formdata(obj.fields,
                                                            obj.files)
        conn = self.get_connection()
        conn.putrequest('POST', self.url_encoder(obj.a10_url))
        conn.putheader('content-type', content_type)
        conn.putheader('Authorization', "A10 %s" % self.session_id)
        conn.putheader('content-length', str(len(body)))
        conn.endheaders()
        conn.send(body)
        response = conn.getresponse()
        conn.close()
        return self.request_handler('MPP', obj, response)


    def encode_multipart_formdata(self, fields, files):
        """
        fields is a sequence of (name, value) elements for regular form fields.
        files is a sequence of (name, filename, value) elements for data to be uploaded as files
        Return (content_type, body) ready for httplib.HTTP instance
        """
        boundkey = "".join([random.SystemRandom().choice(string
                                                         .digits +
                                                         string.letters)
                            for i in range(16)])
        BOUNDARY = "----------" + boundkey
        CRLF = '\r\n'
        L = []

        for (key, value) in fields:
            L.append('--' + BOUNDARY)
            L.append('Content-Disposition: form-data; name="%s"' % key)
            L.append('Content-Type: application/json')
            L.append('')
            if isinstance(value, dict):
                value = json.dumps(value)
            L.append(value)
            L.append('')

        for (key, filename, value) in files:
            L.append('--' + BOUNDARY)
            L.append(
                'Content-Disposition: form-data; name="%s"; filename="%s"' % (
                    key, filename))
            L.append('Content-Type: %s' % self.get_content_type(filename))
            #L.append('Content-transfer-encoding: Base64')
            L.append('')
            #L.append(base64.b64encode(value))
            L.append(value)

        L.append('--' + BOUNDARY + '--')
        L.append('')
        body = CRLF.join(L)
        content_type = 'multipart/form-data; boundary=%s' % BOUNDARY
        return content_type, body


    def get_content_type(self, filename):
        return mimetypes.guess_type(filename)[0] or 'text/plain'


    def multi_part_get(self, obj, query_params=None):
        # Replace the a10_url with just the base path, stripping out any previous querystring
        conn = self.get_connection()
        conn.request("GET", obj.a10_url, "", self.headers)
        response = conn.getresponse()
        conn.close()
        return self.request_handler("GET_MP", obj, response)

    def file_delete(self, obj):
        obj.a10_url = self.url_encoder(obj.a10_url)
        conn = httplib.HTTPSConnection(self.host, port=self.port)
        payload = None
        conn.request("DELETE", self.url_encoder(obj.a10_url), "", self.headers)
        response = conn.getresponse()
        conn.close()
        obj.__setattr__("DEBUG_CONNECTION", conn.__dict__)
        obj.__setattr__("DEBUG_Payload", "")
        obj.__setattr__("DEBUG_Response", response)
        obj.__setattr__("DEBUG_URL", obj.a10_url)
        obj.__setattr__("DEBUG_headers", self.headers)
        return self.request_handler("FD", obj, response)



from a10sdk.common.A10BaseClass import A10BaseClass


class FailSafe(A10BaseClass):
    
    """Class Description::
    Fail Safe Global Commands.

    Class fail-safe supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param session_mem_recovery_threshold: {"description": "Session memory recovery threshold (percentage) (Percentage of available session memory (default 30%))", "format": "number", "default": 30, "optional": true, "maximum": 100, "minimum": 1, "type": "number"}
    :param log: {"description": "Log the event", "format": "flag", "default": 0, "optional": true, "not": "kill", "type": "number"}
    :param fpga_buff_recovery_threshold: {"description": "FPGA buffers recovery threshold (Units of 256 buffers (default 2))", "format": "number", "default": 2, "optional": true, "maximum": 10, "minimum": 1, "type": "number"}
    :param hw_error_recovery_timeout: {"description": "Hardware error recovery timeout (minutes) (waiting time of recovery from hardware errors (default 0))", "format": "number", "type": "number", "maximum": 1440, "minimum": 1, "optional": true}
    :param sw_error_monitor_enable: {"default": 0, "optional": true, "type": "number", "description": "Enable fail-safe software error monitor", "format": "flag"}
    :param hw_error_monitor_disable: {"description": "Disable fail-safe hardware error monitor", "format": "flag", "default": 0, "optional": true, "not": "hw-error-monitor-enable", "type": "number"}
    :param kill: {"description": "Stop the traffic and log the event", "format": "flag", "default": 0, "optional": true, "not": "log", "type": "number"}
    :param hw_error_monitor_enable: {"description": "Enable fail-safe hardware error monitor", "format": "flag", "default": 1, "optional": true, "not": "hw-error-monitor-disable", "type": "number"}
    :param total_memory_size_check: {"description": "Check total memory size of current system (Size of memory (GB))", "format": "number", "type": "number", "maximum": 256, "minimum": 1, "optional": true}
    :param sw_error_recovery_timeout: {"description": "Software error recovery timeout (minutes) (waiting time of recovery from software errors (default 3))", "format": "number", "default": 3, "optional": true, "maximum": 1440, "minimum": 1, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/fail-safe`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "fail-safe"
        self.a10_url="/axapi/v3/fail-safe"
        self.DeviceProxy = ""
        self.session_mem_recovery_threshold = ""
        self.log = ""
        self.fpga_buff_recovery_threshold = ""
        self.hw_error_recovery_timeout = ""
        self.sw_error_monitor_enable = ""
        self.hw_error_monitor_disable = ""
        self.kill = ""
        self.hw_error_monitor_enable = ""
        self.total_memory_size_check = ""
        self.sw_error_recovery_timeout = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class ExtcommunityList(A10BaseClass):
    
    """Class Description::
    Configure Extcommunity-list.

    Class extcommunity-list supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param expanded_num_list: {"minItems": 1, "items": {"type": "expanded-num"}, "uniqueItems": true, "array": [{"required": ["ext-list-num"], "properties": {"ext-list-num": {"description": "Extended Community list number (expanded)", "format": "number", "type": "number", "maximum": 199, "minimum": 100, "optional": false}, "rules-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "ext-list-value": {"type": "string", "description": "An ordered list as a regular-expression", "format": "string-rlx"}, "ext-list-action": {"enum": ["deny", "permit"], "type": "string", "description": "'deny': Specify community to reject; 'permit': Specify community to accept; ", "format": "enum"}}}]}}}], "type": "array", "$ref": "/axapi/v3/ip/extcommunity-list/expanded-num/{ext-list-num}"}
    :param expanded_list: {"minItems": 1, "items": {"type": "expanded"}, "uniqueItems": true, "array": [{"required": ["expanded"], "properties": {"expanded": {"description": "Add an expanded extcommunity-list entry (Extended Community list name)", "format": "string", "minLength": 1, "optional": false, "maxLength": 128, "type": "string"}, "rules-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"expanded-value": {"type": "string", "description": "An ordered list as a regular-expression", "format": "string-rlx"}, "optional": true, "expanded-action": {"enum": ["deny", "permit"], "type": "string", "description": "'deny': Specify community to reject; 'permit': Specify community to accept; ", "format": "enum"}}}]}}}], "type": "array", "$ref": "/axapi/v3/ip/extcommunity-list/expanded/{expanded}"}
    :param standard_num_list: {"minItems": 1, "items": {"type": "standard-num"}, "uniqueItems": true, "array": [{"required": ["std-list-num"], "properties": {"rules-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "std-list-action": {"enum": ["deny", "permit"], "type": "string", "description": "'deny': Specify community to reject; 'permit': Specify community to accept; ", "format": "enum"}, "std-list-value": {"type": "string", "description": "rt Route Target extended community in aa:nn or IPaddr:nn format OR soo Site-of-Origin extended community in aa:nn or IPaddr:nn ", "format": "string-rlx"}}}]}, "std-list-num": {"description": "Extended Community list number (standard)", "format": "number", "type": "number", "maximum": 99, "minimum": 1, "optional": false}}}], "type": "array", "$ref": "/axapi/v3/ip/extcommunity-list/standard-num/{std-list-num}"}
    :param standard_list: {"minItems": 1, "items": {"type": "standard"}, "uniqueItems": true, "array": [{"required": ["standard"], "properties": {"rules-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"standard-action": {"enum": ["deny", "permit"], "type": "string", "description": "'deny': Specify community to reject; 'permit': Specify community to accept; ", "format": "enum"}, "optional": true, "standard-value": {"type": "string", "description": "rt Route Target extended community in aa:nn or IPaddr:nn format OR soo Site-of-Origin extended community in aa:nn or IPaddr:nn ", "format": "string-rlx"}}}]}, "standard": {"description": "Add a standard extcommunity-list entry (Extended Community list name)", "format": "string", "minLength": 1, "optional": false, "maxLength": 128, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/ip/extcommunity-list/standard/{standard}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/ip/extcommunity-list`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "extcommunity-list"
        self.a10_url="/axapi/v3/ip/extcommunity-list"
        self.DeviceProxy = ""
        self.expanded_num_list = []
        self.expanded_list = []
        self.standard_num_list = []
        self.standard_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class ResourceUsage(A10BaseClass):
    
    """Class Description::
    Configure SLB Resource Usage.

    Class resource-usage supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param virtual_server_count: {"platform-specific-range": 1, "platform-specific-default": 1, "description": "Total Virtual Servers in the System", "format": "number", "optional": true, "type": "number"}
    :param nat_pool_addr_count: {"platform-specific-range": 1, "platform-specific-default": 1, "description": "Total configurable NAT Pool addresses in the System", "format": "number", "optional": true, "type": "number"}
    :param fast_tcp_template_count: {"platform-specific-range": 1, "platform-specific-default": 1, "description": "Total configurable Fast TCP Templates in the System", "format": "number", "optional": true, "type": "number"}
    :param virtual_port_count: {"platform-specific-range": 1, "platform-specific-default": 1, "description": "Total Virtual Server Ports in the System", "format": "number", "optional": true, "type": "number"}
    :param proxy_template_count: {"platform-specific-range": 1, "platform-specific-default": 1, "description": "Total configurable Proxy Templates in the System", "format": "number", "optional": true, "type": "number"}
    :param fast_udp_template_count: {"platform-specific-range": 1, "platform-specific-default": 1, "description": "Total configurable Fast UDP Templates in the System", "format": "number", "optional": true, "type": "number"}
    :param client_ssl_template_count: {"platform-specific-range": 1, "platform-specific-default": 1, "description": "Total configurable Client SSL Templates in the System", "format": "number", "optional": true, "type": "number"}
    :param service_group_count: {"platform-specific-range": 1, "platform-specific-default": 1, "description": "Total Service Groups in the System", "format": "number", "optional": true, "type": "number"}
    :param class_list_ipv6_addr_count: {"platform-specific-range": 1, "platform-specific-default": 1, "description": "Total IPv6 addresses for class-list", "format": "number", "optional": true, "type": "number"}
    :param stream_template_count: {"platform-specific-range": 1, "platform-specific-default": 1, "description": "Total configurable Streaming media in the System", "format": "number", "optional": true, "type": "number"}
    :param conn_reuse_template_count: {"platform-specific-range": 1, "platform-specific-default": 1, "description": "Total configurable Connection reuse Templates in the System", "format": "number", "optional": true, "type": "number"}
    :param persist_cookie_template_count: {"platform-specific-range": 1, "platform-specific-default": 1, "description": "Total configurable Persistent cookie Templates in the System", "format": "number", "optional": true, "type": "number"}
    :param persist_srcip_template_count: {"platform-specific-range": 1, "platform-specific-default": 1, "description": "Total configurable Source IP Persistent Templates in the System", "format": "number", "optional": true, "type": "number"}
    :param server_ssl_template_count: {"platform-specific-range": 1, "platform-specific-default": 1, "description": "Total configurable Server SSL Templates in the System", "format": "number", "optional": true, "type": "number"}
    :param real_server_count: {"platform-specific-range": 1, "platform-specific-default": 1, "description": "Total Real Servers in the System", "format": "number", "optional": true, "type": "number"}
    :param real_port_count: {"platform-specific-range": 1, "platform-specific-default": 1, "description": "Total Real Server Ports in the System", "format": "number", "optional": true, "type": "number"}
    :param http_template_count: {"platform-specific-range": 1, "platform-specific-default": 1, "description": "Total configurable HTTP Templates in the System", "format": "number", "optional": true, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/resource-usage`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "resource-usage"
        self.a10_url="/axapi/v3/slb/resource-usage"
        self.DeviceProxy = ""
        self.virtual_server_count = ""
        self.nat_pool_addr_count = ""
        self.fast_tcp_template_count = ""
        self.virtual_port_count = ""
        self.proxy_template_count = ""
        self.fast_udp_template_count = ""
        self.client_ssl_template_count = ""
        self.service_group_count = ""
        self.class_list_ipv6_addr_count = ""
        self.stream_template_count = ""
        self.conn_reuse_template_count = ""
        self.persist_cookie_template_count = ""
        self.persist_srcip_template_count = ""
        self.server_ssl_template_count = ""
        self.real_server_count = ""
        self.real_port_count = ""
        self.http_template_count = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class DnsDomainExpect(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param dns_domain_response: {"minLength": 1, "maxLength": 31, "type": "string", "description": "Specify response code range (e.g. 0,1-5) (Format is xx,xx-xx (xx between [0,15]))", "format": "string-rlx"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "dns-domain-expect"
        self.DeviceProxy = ""
        self.dns_domain_response = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class DnsIpv6Expect(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param dns_ipv6_response: {"minLength": 1, "maxLength": 31, "type": "string", "description": "Specify response code range (e.g. 0,1-5) (Format is xx,xx-xx (xx between [0,15]))", "format": "string-rlx"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "dns-ipv6-expect"
        self.DeviceProxy = ""
        self.dns_ipv6_response = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class DnsIpv4Expect(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param dns_ipv4_response: {"minLength": 1, "maxLength": 31, "type": "string", "description": "Specify response code range (e.g. 0,1-5) (Format is xx,xx-xx (xx between [0,15]))", "format": "string-rlx"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "dns-ipv4-expect"
        self.DeviceProxy = ""
        self.dns_ipv4_response = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Dns(A10BaseClass):
    
    """Class Description::
    DNS type.

    Class dns supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param dns_domain_type: {"optional": true, "enum": ["A", "CNAME", "SOA", "PTR", "MX", "TXT", "AAAA"], "type": "string", "description": "'A': Used for storing Ipv4 address (default); 'CNAME': Canonical name for a DNS alias; 'SOA': Start of authority; 'PTR': Domain name pointer; 'MX': Mail exchanger; 'TXT': Text string; 'AAAA': Used for storing Ipv6 128-bits address; ", "format": "enum"}
    :param dns_domain: {"description": "Specify fully qualified domain name of the host", "format": "string", "minLength": 1, "optional": true, "maxLength": 255, "not": "dns-ip-key", "type": "string"}
    :param dns_domain_recurse: {"description": "'enabled': Set the recursion bit; 'disabled': Clear the recursion bit; ", "format": "enum", "default": "enabled", "type": "string", "enum": ["enabled", "disabled"], "optional": true}
    :param dns_ipv4_recurse: {"description": "'enabled': Set the recursion bit; 'disabled': Clear the recursion bit; ", "format": "enum", "default": "enabled", "type": "string", "enum": ["enabled", "disabled"], "optional": true}
    :param dns_ipv6_port: {"description": "Specify DNS port, default is 53 (DNS Port(default 53))", "format": "number", "default": 53, "optional": true, "maximum": 65534, "minimum": 1, "type": "number"}
    :param dns_ipv4_port: {"description": "Specify DNS port, default is 53 (DNS Port(default 53))", "format": "number", "default": 53, "optional": true, "maximum": 65534, "minimum": 1, "type": "number"}
    :param dns_domain_port: {"description": "Specify DNS port, default is 53 (DNS Port(default 53))", "format": "number", "default": 53, "optional": true, "maximum": 65534, "minimum": 1, "type": "number"}
    :param dns_ipv6_recurse: {"description": "'enabled': Set the recursion bit; 'disabled': Clear the recursion bit; ", "format": "enum", "default": "enabled", "type": "string", "enum": ["enabled", "disabled"], "optional": true}
    :param dns_ipv6_tcp: {"default": 0, "optional": true, "type": "number", "description": "Configure DNS transport over TCP, default is UDP", "format": "flag"}
    :param dns_domain_tcp: {"default": 0, "optional": true, "type": "number", "description": "Configure DNS transport over TCP, default is UDP", "format": "flag"}
    :param dns: {"default": 0, "optional": true, "type": "number", "description": "DNS type", "format": "flag"}
    :param dns_ipv4_tcp: {"default": 0, "optional": true, "type": "number", "description": "Configure DNS transport over TCP, default is UDP", "format": "flag"}
    :param dns_ipv4_addr: {"not": "dns-ipv6-addr", "optional": true, "type": "string", "description": "Specify IPv4 address", "format": "ipv4-address"}
    :param dns_ipv6_addr: {"not": "dns-ipv4-addr", "optional": true, "type": "string", "description": "Specify IPv6 address", "format": "ipv6-address"}
    :param dns_ip_key: {"description": "Reverse DNS lookup (Specify IPv4 or IPv6 address)", "format": "flag", "default": 0, "optional": true, "not": "dns-domain", "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/health/monitor/{name}/method/dns`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "dns"
        self.a10_url="/axapi/v3/health/monitor/{name}/method/dns"
        self.DeviceProxy = ""
        self.dns_domain_type = ""
        self.dns_domain = ""
        self.dns_domain_recurse = ""
        self.dns_ipv4_recurse = ""
        self.dns_ipv6_port = ""
        self.dns_domain_expect = {}
        self.dns_ipv4_port = ""
        self.dns_ipv6_expect = {}
        self.dns_domain_port = ""
        self.dns_ipv6_recurse = ""
        self.dns_ipv6_tcp = ""
        self.dns_ipv4_expect = {}
        self.dns_domain_tcp = ""
        self.dns = ""
        self.dns_ipv4_tcp = ""
        self.dns_ipv4_addr = ""
        self.dns_ipv6_addr = ""
        self.dns_ip_key = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class AdminSession(A10BaseClass):
    
    """    :param clear: {"default": 0, "optional": true, "type": "number", "description": "clear admin session", "format": "flag"}
    :param all: {"default": 0, "optional": true, "type": "number", "description": "Clear all admin sessions", "format": "flag"}
    :param sid: {"description": "Session ID", "format": "number", "default": 0, "optional": true, "maximum": 2147483647, "minimum": 0, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

Class Description::
    Admin session management.

    Class admin-session supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/admin-session`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "admin-session"
        self.a10_url="/axapi/v3/admin-session"
        self.DeviceProxy = ""
        self.clear = ""
        self.A10WW_all = ""
        self.sid = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class ServiceTimeout(A10BaseClass):
    
    """Class Description::
    Specify any custom service timeout.

    Class service-timeout supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param timeout_val: {"description": "Timeout in seconds (Interval of 60 seconds)", "format": "number", "type": "number", "maximum": 15000, "minimum": 2, "optional": true}
    :param service_type: {"optional": false, "enum": ["tcp", "udp"], "type": "string", "description": "'tcp': TCP Protocol; 'udp': UDP Protocol; ", "format": "enum"}
    :param timeout_type: {"optional": true, "enum": ["age", "fast"], "type": "string", "description": "'age': Expiration time; 'fast': Use Fast aging; ", "format": "enum"}
    :param port: {"description": "Port Number", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": false}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/ip/nat/translation/service-timeout/{service_type}+{port}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "service_type","port"]

        self.b_key = "service-timeout"
        self.a10_url="/axapi/v3/ip/nat/translation/service-timeout/{service_type}+{port}"
        self.DeviceProxy = ""
        self.timeout_val = ""
        self.service_type = ""
        self.timeout_type = ""
        self.port = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class ObjectGroup(A10BaseClass):
    
    """Class Description::
    Configure Object Group.

    Class object-group supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param network_list: {"minItems": 1, "items": {"type": "network"}, "uniqueItems": true, "array": [{"required": ["net-name"], "properties": {"rules": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"host-v6": {"type": "string", "description": "IPv6 Host Address", "format": "ipv6-address"}, "subnet": {"type": "string", "description": "IPv4 Network Address", "format": "ipv4-address"}, "host-v4": {"type": "string", "description": "IPv4 Host Address", "format": "ipv4-address"}, "description": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Description of the object-group instance", "format": "string-rlx"}, "ipv6-subnet": {"type": "string", "description": "IPv6 Network Address", "format": "ipv6-address-plen"}, "seq-num": {"description": "Sequence number", "minimum": 1, "type": "number", "maximum": 8192, "format": "number"}, "rev-subnet-mask": {"type": "string", "description": "Network Mask. 0=apply, 255=ignore", "format": "ipv4-rev-netmask"}, "optional": true, "any": {"default": 0, "type": "number", "description": "Any host", "format": "flag"}}}]}, "net-name": {"description": "Network Object Name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/object-group/network/{net-name}"}
    :param service_list: {"minItems": 1, "items": {"type": "service"}, "uniqueItems": true, "array": [{"required": ["svc-name"], "properties": {"rules": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"icmp-type": {"description": "ICMP type number", "format": "number", "not-list": ["any-type", "special-type"], "maximum": 254, "minimum": 0, "type": "number"}, "icmpv6-code": {"description": "ICMPv6 code number", "format": "number", "maximum": 254, "minimum": 0, "not": "v6-any-code", "type": "number"}, "lt-src": {"description": "Match only packets with a lower port number", "minimum": 2, "type": "number", "maximum": 65535, "format": "number"}, "eq-dst": {"description": "Match only packets on a given destination port (port number)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "range-dst": {"description": "Match only packets in the range of port numbers (Starting Destination Port Number)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "seq-num": {"description": "Sequence number", "minimum": 1, "type": "number", "maximum": 8192, "format": "number"}, "source": {"default": 0, "type": "number", "description": "Source Port Information", "format": "flag"}, "eq-src": {"description": "Match only packets on a given source port (port number)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "v6-any-code": {"default": 0, "not": "icmpv6-code", "type": "number", "description": "Any ICMPv6 code", "format": "flag"}, "icmpv6-type": {"description": "ICMPv6 type number", "format": "number", "not-list": ["v6-any-type", "special-v6-type"], "maximum": 254, "minimum": 0, "type": "number"}, "icmp-code": {"description": "ICMP code number", "format": "number", "maximum": 254, "minimum": 0, "not": "any-code", "type": "number"}, "description": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Description of the object-group instance", "format": "string-rlx"}, "special-code": {"not": "icmp-code", "enum": ["frag-required", "host-unreachable", "network-unreachable", "port-unreachable", "proto-unreachable", "route-failed"], "type": "string", "description": "'frag-required': Code 4, fragmentation required; 'host-unreachable': Code 1, destination host unreachable; 'network-unreachable': Code 0, destination network unreachable; 'port-unreachable': Code 3, destination port unreachable; 'proto-unreachable': Code 2, destination protocol unreachable; 'route-failed': Code 5, source route failed; ", "format": "enum"}, "tcp-udp": {"enum": ["tcp", "udp"], "type": "string", "description": "'tcp': Protocol TCP; 'udp': Protocol UDP; ", "format": "enum"}, "gt-dst": {"description": "Match only packets with a greater port number", "minimum": 1, "type": "number", "maximum": 65534, "format": "number"}, "icmp": {"default": 0, "type": "number", "description": "Internet Control Message Protocol", "format": "flag"}, "optional": true, "port-num-end-src": {"description": "Ending Port Number", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "special-v6-type": {"not-list": ["icmpv6-type", "v6-any-type"], "enum": ["dest-unreachable", "echo-reply", "echo-request", "packet-too-big", "param-prob", "time-exceeded"], "type": "string", "description": "'dest-unreachable': Type 1, destination unreachable; 'echo-reply': Type 129, echo reply; 'echo-request': Type 128, echo request; 'packet-too-big': Type 2, packet too big; 'param-prob': Type 4, parameter problem; 'time-exceeded': Type 3, time exceeded; ", "format": "enum"}, "any-type": {"default": 0, "not-list": ["icmp-type", "special-type"], "type": "number", "description": "Any ICMP type", "format": "flag"}, "lt-dst": {"description": "Match only packets with a lesser port number", "minimum": 2, "type": "number", "maximum": 65535, "format": "number"}, "gt-src": {"description": "Match only packets with a greater port number", "minimum": 1, "type": "number", "maximum": 65534, "format": "number"}, "special-v6-code": {"not": "icmpv6-code", "enum": ["addr-unreachable", "admin-prohibited", "no-route", "not-neighbour", "port-unreachable"], "type": "string", "description": "'addr-unreachable': Code 3, address unreachable; 'admin-prohibited': Code 1, admin prohibited; 'no-route': Code 0, no route to destination; 'not-neighbour': Code 2, not neighbor; 'port-unreachable': Code 4, destination port unreachable; ", "format": "enum"}, "icmpv6": {"default": 0, "type": "number", "description": "Internet Control Message Protocol version 6", "format": "flag"}, "range-src": {"description": "match only packets in the range of port numbers (Starting Port Number)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "port-num-end-dst": {"description": "Ending Destination Port Number", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "v6-any-type": {"default": 0, "not-list": ["icmpv6-type", "special-v6-type"], "type": "number", "description": "Any ICMP type", "format": "flag"}, "any-code": {"default": 0, "not": "icmp-code", "type": "number", "description": "Any ICMP code", "format": "flag"}, "special-type": {"not-list": ["icmp-type", "any-type"], "enum": ["echo-reply", "echo-request", "info-reply", "info-request", "mask-reply", "mask-request", "parameter-problem", "redirect", "source-quench", "time-exceeded", "timestamp", "timestamp-reply", "dest-unreachable"], "type": "string", "description": "'echo-reply': Type 0, echo reply; 'echo-request': Type 8, echo request; 'info-reply': Type 16, information reply; 'info-request': Type 15, information request; 'mask-reply': Type 18, address mask reply; 'mask-request': Type 17, address mask request; 'parameter-problem': Type 12, parameter problem; 'redirect': Type 5, redirect message; 'source-quench': Type 4, source quench; 'time-exceeded': Type 11, time exceeded; 'timestamp': Type 13, timestamp; 'timestamp-reply': Type 14, timestamp reply; 'dest-unreachable': Type 3, destination unreachable; ", "format": "enum"}}}]}, "svc-name": {"description": "Service Object Name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/object-group/service/{svc-name}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/object-group`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "object-group"
        self.a10_url="/axapi/v3/object-group"
        self.DeviceProxy = ""
        self.network_list = []
        self.service_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Password(A10BaseClass):
    
    """Class Description::
    Config admin user password.

    Class password supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param password_in_module: {"description": "Config admin user password", "format": "password", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param encrypted_in_module: {"optional": true, "type": "encrypted", "description": "Specify an ENCRYPTED password string (System admin user password)", "format": "encrypted"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/admin/{user}/password`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "password"
        self.a10_url="/axapi/v3/admin/{user}/password"
        self.DeviceProxy = ""
        self.password_in_module = ""
        self.encrypted_in_module = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Ntlm(A10BaseClass):
    
    """Class Description::
    NTLM Authentication Relay.

    Class ntlm supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param domain: {"description": "Specify NTLM domain, default is null", "format": "string", "minLength": 1, "optional": true, "maxLength": 64, "type": "string"}
    :param version: {"description": "Specify NTLM version, default is NTLM 2", "format": "number", "default": 2, "optional": true, "maximum": 2, "minimum": 1, "type": "number"}
    :param name: {"description": "Specify NTLM authentication relay name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/aam/authentication/relay/ntlm/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "ntlm"
        self.a10_url="/axapi/v3/aam/authentication/relay/ntlm/{name}"
        self.DeviceProxy = ""
        self.domain = ""
        self.version = ""
        self.name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param bwl_drop: {"description": "BW Limit Drop", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "8"}
    :param pingofdeath_drop: {"description": "Anomaly PingDeath Drop", "format": "counter", "type": "number", "oid": "32", "optional": true, "size": "8"}
    :param l2_forward: {"description": "L2 Forward", "format": "counter", "type": "number", "oid": "12", "optional": true, "size": "8"}
    :param jumbo_frag_drop: {"description": "Jumbo Frag Drop", "format": "counter", "type": "number", "oid": "63", "optional": true, "size": "8"}
    :param ipv6frag_tcp_dropped: {"description": "IPv6 Frag TCP Dropped", "format": "counter", "type": "number", "oid": "47", "optional": true, "size": "8"}
    :param rx_arp_req: {"description": "ARP REQ Rcvd", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "8"}
    :param ipv4_frag_6rd_ok: {"description": "IPv4 Frag 6RD OK", "format": "counter", "type": "number", "oid": "42", "optional": true, "size": "8"}
    :param fwlb: {"description": "FWLB", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}
    :param ipfrag_tcp: {"description": "IP(TCP) Fragment Rcvd", "format": "counter", "type": "number", "oid": "23", "optional": true, "size": "8"}
    :param l2_def_vlan_drop: {"description": "L2 Default Vlan FWD Drop", "format": "counter", "type": "number", "oid": "8", "optional": true, "size": "8"}
    :param ipipv6_jumbo_frag_drop: {"description": "IPIPv6 Jumbo Frag Drop", "format": "counter", "type": "number", "oid": "65", "optional": true, "size": "8"}
    :param vlan_flood: {"description": "VLAN Flood", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "8"}
    :param ipv6frag_ipip_ok: {"description": "IPv6 Frag IPIP OKs", "format": "counter", "type": "number", "oid": "48", "optional": true, "size": "8"}
    :param max_arp_drop: {"description": "Max ARP Drop", "format": "counter", "type": "number", "oid": "56", "optional": true, "size": "8"}
    :param ipv4_frag_6rd_drop: {"description": "IPv4 Frag 6RD Dropped", "format": "counter", "type": "number", "oid": "43", "optional": true, "size": "8"}
    :param prot_down_drop: {"description": "Prot Down Drop", "format": "counter", "type": "number", "oid": "11", "optional": true, "size": "8"}
    :param ipfrag_reasmoks: {"description": "IP Fragment Reasm OKs", "format": "counter", "type": "number", "oid": "27", "optional": true, "size": "8"}
    :param rx_kernel: {"description": "Received kernel", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "8"}
    :param bpdu_rcvd: {"description": "BPDUs Received", "format": "counter", "type": "number", "oid": "38", "optional": true, "size": "8"}
    :param ttl_exceeded_drop: {"description": "TTL Exceeded Drop", "format": "counter", "type": "number", "oid": "17", "optional": true, "size": "8"}
    :param ipv6frag_ospf: {"description": "IPv6 Frag OSPF", "format": "counter", "type": "number", "oid": "59", "optional": true, "size": "8"}
    :param land_drop: {"description": "Anomaly Land Attack Drop", "format": "counter", "type": "number", "oid": "29", "optional": true, "size": "8"}
    :param ipv6frag_icmp: {"description": "IPv6 Frag ICMP", "format": "counter", "type": "number", "oid": "58", "optional": true, "size": "8"}
    :param ctrl_syn_rate_drop: {"description": "SYN rate exceeded Drop", "format": "counter", "type": "number", "oid": "40", "optional": true, "size": "8"}
    :param ipv6frag_udp_dropped: {"description": "IPv6 Frag UDP Dropped", "format": "counter", "type": "number", "oid": "46", "optional": true, "size": "8"}
    :param rx_arp_resp: {"description": "ARP RESP Rcvd", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "8"}
    :param allfrag_drop: {"description": "Anomaly All Frag Drop", "format": "counter", "type": "number", "oid": "33", "optional": true, "size": "8"}
    :param ip_defrag: {"description": "IP Defrag", "format": "counter", "type": "number", "oid": "21", "optional": true, "size": "8"}
    :param incorrect_len_drop: {"description": "Incorrect Length Drop", "format": "counter", "type": "number", "oid": "20", "optional": true, "size": "8"}
    :param ipv6_ndisc_mac_changes: {"description": "IPv6 DAD MAC Changed", "format": "counter", "type": "number", "oid": "68", "optional": true, "size": "8"}
    :param l4_process: {"description": "L4 Process", "format": "counter", "type": "number", "oid": "15", "optional": true, "size": "8"}
    :param linkdown_drop: {"description": "Link Down Drop", "format": "counter", "type": "number", "oid": "18", "optional": true, "size": "8"}
    :param ipv6frag_tcp: {"description": "IPv6 Frag TCP", "format": "counter", "type": "number", "oid": "57", "optional": true, "size": "8"}
    :param tcpnoflag_drop: {"description": "Anomaly TCP noFlag Drop", "format": "counter", "type": "number", "oid": "34", "optional": true, "size": "8"}
    :param ipoptions_drop: {"description": "Anomaly IP OPT Drops", "format": "counter", "type": "number", "oid": "30", "optional": true, "size": "8"}
    :param ip_defrag_invalid_len: {"description": "IP Invalid Length Frag", "format": "counter", "type": "number", "oid": "41", "optional": true, "size": "8"}
    :param ipv6_ndisc_out_of_memory: {"description": "IPv6 DAD Out-of-memory", "format": "counter", "type": "number", "oid": "69", "optional": true, "size": "8"}
    :param ipfrag_reasmfails: {"description": "IP Fragment Reasm Fails", "format": "counter", "type": "number", "oid": "28", "optional": true, "size": "8"}
    :param ipv6_jumbo_frag_drop: {"description": "IPv6 Jumbo Frag Drop", "format": "counter", "type": "number", "oid": "64", "optional": true, "size": "8"}
    :param ipv6_ndisc_dad_adverts: {"description": "IPv6 DAD on Adverts", "format": "counter", "type": "number", "oid": "67", "optional": true, "size": "8"}
    :param l4_in_ctrl_cpu: {"description": "L4 In Ctrl CPU", "format": "counter", "type": "number", "oid": "61", "optional": true, "size": "8"}
    :param fpga_error_pkt1: {"description": "FPGA Error PKT1", "format": "counter", "type": "number", "oid": "54", "optional": true, "size": "8"}
    :param fpga_error_pkt2: {"description": "FPGA Error PKT2", "format": "counter", "type": "number", "oid": "55", "optional": true, "size": "8"}
    :param tcpsynfrag_drop: {"description": "Anomaly SYN Frag Drop", "format": "counter", "type": "number", "oid": "35", "optional": true, "size": "8"}
    :param ipfrag_overload: {"description": "IP Frag Overload Drops", "format": "counter", "type": "number", "oid": "26", "optional": true, "size": "8"}
    :param ipv6frag_ipip_dropped: {"description": "IPv6 Frag IPIP Drop", "format": "counter", "type": "number", "oid": "49", "optional": true, "size": "8"}
    :param mgmt_svc_drop: {"description": "Management Service Drop", "format": "counter", "type": "number", "oid": "62", "optional": true, "size": "8"}
    :param ipv6_ndisc_dad_solicits: {"description": "IPv6 DAD on Solicits", "format": "counter", "type": "number", "oid": "66", "optional": true, "size": "8"}
    :param sport_drop: {"description": "SPORT Drop", "format": "counter", "type": "number", "oid": "19", "optional": true, "size": "8"}
    :param ipfrag_overlap: {"description": "IP Fragment Overlap", "format": "counter", "type": "number", "oid": "24", "optional": true, "size": "8"}
    :param ipv6_noroute_drop: {"description": "IPv6 No Route Drop", "format": "counter", "type": "number", "oid": "10", "optional": true, "size": "8"}
    :param no_ip_drop: {"description": "No IP Drop", "format": "counter", "type": "number", "oid": "44", "optional": true, "size": "8"}
    :param ipv4_noroute_drop: {"description": "IPv4 No Route Drop", "format": "counter", "type": "number", "oid": "9", "optional": true, "size": "8"}
    :param tcpsynfin_drop: {"description": "Anomaly TCP SYNFIN Drop", "format": "counter", "type": "number", "oid": "36", "optional": true, "size": "8"}
    :param ipsec_drop: {"description": "IPSec Drop", "format": "counter", "type": "number", "oid": "37", "optional": true, "size": "8"}
    :param bpdu_sent: {"description": "BPDUs Sent", "format": "counter", "type": "number", "oid": "39", "optional": true, "size": "8"}
    :param ipfrag_timeout: {"description": "IP Fragment Timeout", "format": "counter", "type": "number", "oid": "25", "optional": true, "size": "8"}
    :param l3_forward_ip: {"description": "L3 IP Forward", "format": "counter", "type": "number", "oid": "13", "optional": true, "size": "8"}
    :param ip_frag_too_many: {"description": "IP Fragment too many", "format": "counter", "type": "number", "oid": "51", "optional": true, "size": "8"}
    :param ipv6frag_esp: {"description": "IPv6 Frag ESP", "format": "counter", "type": "number", "oid": "60", "optional": true, "size": "8"}
    :param licexpire_drop: {"description": "License Expire Drop", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "8"}
    :param l3_forward_ipv6: {"description": "L3 IPv6 Forward", "format": "counter", "type": "number", "oid": "14", "optional": true, "size": "8"}
    :param acl_deny: {"description": "ACL Denys", "format": "counter", "type": "number", "oid": "22", "optional": true, "size": "8"}
    :param ip_frag_oversize: {"description": "IP Fragment oversize", "format": "counter", "type": "number", "oid": "50", "optional": true, "size": "8"}
    :param ipv6_novlanfwd_drop: {"description": "IPv6 No L3 VLAN FWD Drop", "format": "counter", "type": "number", "oid": "53", "optional": true, "size": "8"}
    :param unknown_prot_drop: {"description": "Unknown Prot Drop", "format": "counter", "type": "number", "oid": "16", "optional": true, "size": "8"}
    :param ipv4_novlanfwd_drop: {"description": "IPv4 No L3 VLAN FWD Drop", "format": "counter", "type": "number", "oid": "52", "optional": true, "size": "8"}
    :param badpkt_drop: {"description": "Bad Pkt Drop", "format": "counter", "type": "number", "oid": "31", "optional": true, "size": "8"}
    :param ipv6frag_udp: {"description": "IPv6 Frag UDP", "format": "counter", "type": "number", "oid": "45", "optional": true, "size": "8"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.bwl_drop = ""
        self.pingofdeath_drop = ""
        self.l2_forward = ""
        self.jumbo_frag_drop = ""
        self.ipv6frag_tcp_dropped = ""
        self.rx_arp_req = ""
        self.ipv4_frag_6rd_ok = ""
        self.fwlb = ""
        self.ipfrag_tcp = ""
        self.l2_def_vlan_drop = ""
        self.ipipv6_jumbo_frag_drop = ""
        self.vlan_flood = ""
        self.ipv6frag_ipip_ok = ""
        self.max_arp_drop = ""
        self.ipv4_frag_6rd_drop = ""
        self.prot_down_drop = ""
        self.ipfrag_reasmoks = ""
        self.rx_kernel = ""
        self.bpdu_rcvd = ""
        self.ttl_exceeded_drop = ""
        self.ipv6frag_ospf = ""
        self.land_drop = ""
        self.ipv6frag_icmp = ""
        self.ctrl_syn_rate_drop = ""
        self.ipv6frag_udp_dropped = ""
        self.rx_arp_resp = ""
        self.allfrag_drop = ""
        self.ip_defrag = ""
        self.incorrect_len_drop = ""
        self.ipv6_ndisc_mac_changes = ""
        self.l4_process = ""
        self.linkdown_drop = ""
        self.ipv6frag_tcp = ""
        self.tcpnoflag_drop = ""
        self.ipoptions_drop = ""
        self.ip_defrag_invalid_len = ""
        self.ipv6_ndisc_out_of_memory = ""
        self.ipfrag_reasmfails = ""
        self.ipv6_jumbo_frag_drop = ""
        self.ipv6_ndisc_dad_adverts = ""
        self.l4_in_ctrl_cpu = ""
        self.fpga_error_pkt1 = ""
        self.fpga_error_pkt2 = ""
        self.tcpsynfrag_drop = ""
        self.ipfrag_overload = ""
        self.ipv6frag_ipip_dropped = ""
        self.mgmt_svc_drop = ""
        self.ipv6_ndisc_dad_solicits = ""
        self.sport_drop = ""
        self.ipfrag_overlap = ""
        self.ipv6_noroute_drop = ""
        self.no_ip_drop = ""
        self.ipv4_noroute_drop = ""
        self.tcpsynfin_drop = ""
        self.ipsec_drop = ""
        self.bpdu_sent = ""
        self.ipfrag_timeout = ""
        self.l3_forward_ip = ""
        self.ip_frag_too_many = ""
        self.ipv6frag_esp = ""
        self.licexpire_drop = ""
        self.l3_forward_ipv6 = ""
        self.acl_deny = ""
        self.ip_frag_oversize = ""
        self.ipv6_novlanfwd_drop = ""
        self.unknown_prot_drop = ""
        self.ipv4_novlanfwd_drop = ""
        self.badpkt_drop = ""
        self.ipv6frag_udp = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Switch(A10BaseClass):
    
    """Class Description::
    Statistics for the object switch.

    Class switch supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/switch/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "switch"
        self.a10_url="/axapi/v3/slb/switch/stats"
        self.DeviceProxy = ""
        self.stats = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Slb(A10BaseClass):
    
    """Class Description::
    Enable GSLB group traps.

    Class slb supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param all: {"default": 0, "optional": true, "type": "number", "description": "Enable all SLB traps", "format": "flag"}
    :param vip_up: {"default": 0, "optional": true, "type": "number", "description": "Enable SLB virtual server up trap", "format": "flag"}
    :param vip_connlimit: {"default": 0, "optional": true, "type": "number", "description": "Enable the virtual server reach conn-limit trap", "format": "flag"}
    :param server_down: {"default": 0, "optional": true, "type": "number", "description": "Enable SLB server-down trap", "format": "flag"}
    :param server_conn_resume: {"default": 0, "optional": true, "type": "number", "description": "Enable SLB server connection resume trap", "format": "flag"}
    :param service_up: {"default": 0, "optional": true, "type": "number", "description": "Enable SLB service-up trap", "format": "flag"}
    :param vip_port_up: {"default": 0, "optional": true, "type": "number", "description": "Enable SLB virtual port up trap", "format": "flag"}
    :param service_down: {"default": 0, "optional": true, "type": "number", "description": "Enable SLB service-down trap", "format": "flag"}
    :param vip_port_connratelimit: {"default": 0, "optional": true, "type": "number", "description": "Enable the virtual port reach conn-rate-limit trap", "format": "flag"}
    :param service_conn_limit: {"default": 0, "optional": true, "type": "number", "description": "Enable SLB service connection limit trap", "format": "flag"}
    :param vip_connratelimit: {"default": 0, "optional": true, "type": "number", "description": "Enable the virtual server reach conn-rate-limit trap", "format": "flag"}
    :param server_selection_failure: {"default": 0, "optional": true, "type": "number", "description": "Enable SLB server selection failure trap", "format": "flag"}
    :param vip_port_connlimit: {"default": 0, "optional": true, "type": "number", "description": "Enable the virtual port reach conn-limit trap", "format": "flag"}
    :param server_conn_limit: {"default": 0, "optional": true, "type": "number", "description": "Enable SLB server connection limit trap", "format": "flag"}
    :param vip_port_down: {"default": 0, "optional": true, "type": "number", "description": "Enable SLB virtual port down trap", "format": "flag"}
    :param service_conn_resume: {"default": 0, "optional": true, "type": "number", "description": "Enable SLB service connection resume trap", "format": "flag"}
    :param server_up: {"default": 0, "optional": true, "type": "number", "description": "Enable slb server up trap", "format": "flag"}
    :param vip_down: {"default": 0, "optional": true, "type": "number", "description": "Enable SLB virtual server down trap", "format": "flag"}
    :param application_buffer_limit: {"default": 0, "optional": true, "type": "number", "description": "Enable application buffer reach limit trap", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/snmp-server/enable/traps/slb`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "slb"
        self.a10_url="/axapi/v3/snmp-server/enable/traps/slb"
        self.DeviceProxy = ""
        self.A10WW_all = ""
        self.vip_up = ""
        self.vip_connlimit = ""
        self.server_down = ""
        self.server_conn_resume = ""
        self.service_up = ""
        self.vip_port_up = ""
        self.service_down = ""
        self.vip_port_connratelimit = ""
        self.service_conn_limit = ""
        self.vip_connratelimit = ""
        self.server_selection_failure = ""
        self.vip_port_connlimit = ""
        self.server_conn_limit = ""
        self.vip_port_down = ""
        self.service_conn_resume = ""
        self.server_up = ""
        self.vip_down = ""
        self.application_buffer_limit = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class ResourceUsage(A10BaseClass):
    
    """Class Description::
    Configure CGNV6 Resource Usage.

    Class resource-usage supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param lsn_nat_addr_count: {"platform-specific-range": 1, "platform-specific-default": 1, "description": "Total configurable CGNV6 NAT Pool addresses", "format": "number", "optional": true, "type": "number"}
    :param fixed_nat_ip_addr_count: {"platform-specific-range": 1, "platform-specific-default": 1, "description": "Total configurable CGNV6 Fixed NAT addresses", "format": "number", "optional": true, "type": "number"}
    :param fixed_nat_inside_user_count: {"platform-specific-range": 1, "platform-specific-default": 1, "description": "Total configurable CGNV6 Fixed NAT inside users", "format": "number", "optional": true, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/resource-usage`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "resource-usage"
        self.a10_url="/axapi/v3/cgnv6/resource-usage"
        self.DeviceProxy = ""
        self.lsn_nat_addr_count = ""
        self.fixed_nat_ip_addr_count = ""
        self.fixed_nat_inside_user_count = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class UntaggedTrunkList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param untagged_trunk_start: {"type": "number", "description": "Trunk groups", "format": "number"}
    :param untagged_trunk_end: {"type": "number", "description": "Trunk Group", "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "untagged-trunk-list"
        self.DeviceProxy = ""
        self.untagged_trunk_start = ""
        self.untagged_trunk_end = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class UntaggedEthList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param untagged_ethernet_end: {"type": "number", "description": "Ethernet port", "format": "interface"}
    :param untagged_ethernet_start: {"$ref": "/axapi/v3/interface/ethernet", "type": "number", "description": "Ethernet port (Interface number)", "format": "interface"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "untagged-eth-list"
        self.DeviceProxy = ""
        self.untagged_ethernet_end = ""
        self.untagged_ethernet_start = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class TaggedEthList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param tagged_ethernet_end: {"type": "number", "description": "Ethernet port", "format": "interface"}
    :param tagged_ethernet_start: {"$ref": "/axapi/v3/interface/ethernet", "type": "number", "description": "Ethernet port (Interface number)", "format": "interface"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "tagged-eth-list"
        self.DeviceProxy = ""
        self.tagged_ethernet_end = ""
        self.tagged_ethernet_start = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class TaggedTrunkList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param tagged_trunk_start: {"type": "number", "description": "Trunk groups", "format": "number"}
    :param tagged_trunk_end: {"type": "number", "description": "Trunk Group", "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "tagged-trunk-list"
        self.DeviceProxy = ""
        self.tagged_trunk_start = ""
        self.tagged_trunk_end = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Vlan(A10BaseClass):
    
    """Class Description::
    Configure VLAN.

    Class vlan supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param ve: {"description": "ve number", "format": "number", "type": "number", "maximum": 4094, "minimum": 2, "optional": true}
    :param untagged_trunk_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"untagged-trunk-start": {"type": "number", "description": "Trunk groups", "format": "number"}, "optional": true, "untagged-trunk-end": {"type": "number", "description": "Trunk Group", "format": "number"}}}]}
    :param untagged_lif: {"description": "Logical tunnel interface (Logical tunnel interface number)", "format": "number", "type": "number", "maximum": 128, "minimum": 1, "optional": true}
    :param untagged_eth_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"untagged-ethernet-end": {"type": "number", "description": "Ethernet port", "format": "interface"}, "untagged-ethernet-start": {"$ref": "/axapi/v3/interface/ethernet", "type": "number", "description": "Ethernet port (Interface number)", "format": "interface"}, "optional": true}}]}
    :param tagged_eth_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"tagged-ethernet-end": {"type": "number", "description": "Ethernet port", "format": "interface"}, "optional": true, "tagged-ethernet-start": {"$ref": "/axapi/v3/interface/ethernet", "type": "number", "description": "Ethernet port (Interface number)", "format": "interface"}}}]}
    :param tagged_trunk_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "tagged-trunk-start": {"type": "number", "description": "Trunk groups", "format": "number"}, "tagged-trunk-end": {"type": "number", "description": "Trunk Group", "format": "number"}}}]}
    :param vlan_num: {"description": "VLAN number", "format": "number", "type": "number", "maximum": 4094, "minimum": 2, "optional": false}
    :param name: {"description": "VLAN name", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/network/vlan/{vlan_num}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "vlan_num"]

        self.b_key = "vlan"
        self.a10_url="/axapi/v3/network/vlan/{vlan_num}"
        self.DeviceProxy = ""
        self.ve = ""
        self.untagged_trunk_list = []
        self.untagged_lif = ""
        self.untagged_eth_list = []
        self.tagged_eth_list = []
        self.tagged_trunk_list = []
        self.vlan_num = ""
        self.name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class ReceiveCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param receive: {"default": 0, "type": "number", "description": "Advertisement reception", "format": "flag"}
    :param version: {"enum": ["1", "2", "1-2"], "type": "string", "description": "'1': RIP version 1; '2': RIP version 2; '1-2': RIP version 1 & 2; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "receive-cfg"
        self.DeviceProxy = ""
        self.receive = ""
        self.version = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class SplitHorizonCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param state: {"default": "poisoned", "enum": ["poisoned", "disable", "enable"], "type": "string", "description": "'poisoned': Perform split horizon with poisoned reverse; 'disable': Disable split horizon; 'enable': Perform split horizon without poisoned reverse; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "split-horizon-cfg"
        self.DeviceProxy = ""
        self.state = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class KeyChain(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param key_chain: {"type": "string", "description": "Authentication key-chain (Name of key-chain)", "format": "string-rlx"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "key-chain"
        self.DeviceProxy = ""
        self.key_chain = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Mode(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param mode: {"default": "text", "enum": ["md5", "text"], "type": "string", "description": "'md5': Keyed message digest; 'text': Clear text authentication; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "mode"
        self.DeviceProxy = ""
        self.mode = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Str(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param string: {"minLength": 1, "maxLength": 16, "type": "string", "description": "The RIP authentication string", "format": "string-rlx"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "str"
        self.DeviceProxy = ""
        self.string = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Authentication(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "authentication"
        self.DeviceProxy = ""
        self.key_chain = {}
        self.mode = {}
        self.A10WW_str = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class SendCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param version: {"enum": ["1", "2", "1-compatible", "1-2"], "type": "string", "description": "'1': RIP version 1; '2': RIP version 2; '1-compatible': RIPv1-compatible; '1-2': RIP version 1 & 2; ", "format": "enum"}
    :param send: {"default": 0, "type": "number", "description": "Advertisement transmission", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "send-cfg"
        self.DeviceProxy = ""
        self.version = ""
        self.send = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Rip(A10BaseClass):
    
    """Class Description::
    RIP.

    Class rip supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param receive_packet: {"default": 1, "optional": true, "type": "number", "description": "Enable receiving packet through the specified interface", "format": "flag"}
    :param send_packet: {"default": 1, "optional": true, "type": "number", "description": "Enable sending packets through the specified interface", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/interface/lif/{ifnum}/ip/rip`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "rip"
        self.a10_url="/axapi/v3/interface/lif/{ifnum}/ip/rip"
        self.DeviceProxy = ""
        self.receive_cfg = {}
        self.receive_packet = ""
        self.split_horizon_cfg = {}
        self.authentication = {}
        self.send_cfg = {}
        self.send_packet = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Frag(A10BaseClass):
    
    """Class Description::
    IP fragmentation parameters.

    Class frag supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param max_reassembly_sessions: {"description": "Max number of pending reassembly sessions allowed (default 100000)", "format": "number", "type": "number", "maximum": 200000, "minimum": 1, "optional": true}
    :param timeout: {"description": "Fragmentation timeout (in milliseconds 4 - 16000 (default is 1000))", "format": "number", "type": "number", "maximum": 16000, "minimum": 4, "optional": true}
    :param buff: {"description": "Max buff used for fragmentation (Buffer Value(10000-3000000))", "format": "number", "type": "number", "maximum": 3000000, "minimum": 10000, "optional": true}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/ip/frag`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "frag"
        self.a10_url="/axapi/v3/ip/frag"
        self.DeviceProxy = ""
        self.max_reassembly_sessions = ""
        self.timeout = ""
        self.buff = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class StunTimeout(A10BaseClass):
    
    """Class Description::
    Set STUN timeout for endpoint-independent filtering.

    Class stun-timeout supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param stun_timeout_val_port_range: {"description": "STUN timeout (default: 2 minutes)", "format": "number", "default": 2, "optional": true, "maximum": 60, "minimum": 0, "type": "number"}
    :param port: {"description": "Single Destination Port or Port Range Start", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": false}
    :param port_end: {"description": "Port Range End", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": false}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/stateful-firewall/stun-timeout/{port}+{port_end}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "port","port_end"]

        self.b_key = "stun-timeout"
        self.a10_url="/axapi/v3/cgnv6/stateful-firewall/stun-timeout/{port}+{port_end}"
        self.DeviceProxy = ""
        self.stun_timeout_val_port_range = ""
        self.port = ""
        self.port_end = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param invalid_frame_size: {"description": "Invalid frame size", "format": "counter", "type": "number", "oid": "69", "optional": true, "size": "2"}
    :param data_cb_no_tuple: {"description": "Data callback no tuple", "format": "counter", "type": "number", "oid": "36", "optional": true, "size": "2"}
    :param compress_ctx_alloc_fail: {"description": "Compression context allocation fail", "format": "counter", "type": "number", "oid": "72", "optional": true, "size": "2"}
    :param stream_found: {"description": "Stream found", "format": "counter", "type": "number", "oid": "40", "optional": true, "size": "2"}
    :param total_proxy: {"description": "Total Proxy Conns", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "2"}
    :param curr_http_proxy: {"description": "Curr HTTP Proxy Conns", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "2"}
    :param total_v2_proxy: {"description": "Version 2 Streams", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "2"}
    :param syn_stream_exist_or_even: {"description": "Stream already exists", "format": "counter", "type": "number", "oid": "61", "optional": true, "size": "2"}
    :param close_stream_stream_not_found: {"description": "Close stream stream not found", "format": "counter", "type": "number", "oid": "42", "optional": true, "size": "2"}
    :param client_rst: {"optional": true, "size": "2", "type": "number", "oid": "10", "format": "counter"}
    :param est_cb_no_tuple: {"description": "Est callback no tuple", "format": "counter", "type": "number", "oid": "35", "optional": true, "size": "2"}
    :param stream_alloc_fail: {"description": "Stream alloc fail", "format": "counter", "type": "number", "oid": "47", "optional": true, "size": "2"}
    :param max_concurrent_stream_limit: {"description": "Max concurrent stream limit", "format": "counter", "type": "number", "oid": "46", "optional": true, "size": "2"}
    :param deflate_ctx: {"description": "Deflate context", "format": "counter", "type": "number", "oid": "16", "optional": true, "size": "2"}
    :param client_goaway: {"optional": true, "size": "2", "type": "number", "oid": "12", "format": "counter"}
    :param ping_sent: {"description": "PING sent", "format": "counter", "type": "number", "oid": "17", "optional": true, "size": "2"}
    :param server_goaway: {"description": "Server GOAWAY sent", "format": "counter", "type": "number", "oid": "13", "optional": true, "size": "2"}
    :param session_needs_requeue: {"description": "Session needs requeue", "format": "counter", "type": "number", "oid": "77", "optional": true, "size": "2"}
    :param syn_reply_alr_rcvd: {"description": "SYN reply already received", "format": "counter", "type": "number", "oid": "63", "optional": true, "size": "2"}
    :param total_http_proxy: {"description": "Total HTTP Proxy Conns", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "2"}
    :param close_stream_session_close: {"description": "Stream close session close", "format": "counter", "type": "number", "oid": "44", "optional": true, "size": "2"}
    :param decompress_fail: {"description": "Decompress fail", "format": "counter", "type": "number", "oid": "58", "optional": true, "size": "2"}
    :param ping_frame: {"description": "Ping frame received", "format": "counter", "type": "number", "oid": "30", "optional": true, "size": "2"}
    :param inflate_ctx: {"description": "Inflate context", "format": "counter", "type": "number", "oid": "15", "optional": true, "size": "2"}
    :param name_value_total_len_ex: {"description": "Name value total length exceeded", "format": "counter", "type": "number", "oid": "50", "optional": true, "size": "2"}
    :param http_err_stream_closed: {"description": "HTTP error stream already closed", "format": "counter", "type": "number", "oid": "81", "optional": true, "size": "2"}
    :param http_hdr_stream_close: {"description": "HTTP header stream already closed", "format": "counter", "type": "number", "oid": "82", "optional": true, "size": "2"}
    :param http_data_stream_close: {"description": "HTTP data stream already closed", "format": "counter", "type": "number", "oid": "83", "optional": true, "size": "2"}
    :param control_frame: {"description": "Control frame received", "format": "counter", "type": "number", "oid": "24", "optional": true, "size": "2"}
    :param session_close: {"description": "Session close", "format": "counter", "type": "number", "oid": "84", "optional": true, "size": "2"}
    :param name_value_connection: {"description": "Name value connection", "format": "counter", "type": "number", "oid": "53", "optional": true, "size": "2"}
    :param fin_stream_closed: {"description": "HTTP FIN stream already closed", "format": "counter", "type": "number", "oid": "79", "optional": true, "size": "2"}
    :param stream_close: {"description": "Stream close", "format": "counter", "type": "number", "oid": "21", "optional": true, "size": "2"}
    :param total_stream: {"description": "Total Streams", "format": "counter", "type": "number", "oid": "8", "optional": true, "size": "2"}
    :param window_no_stream: {"description": "Window update no stream found", "format": "counter", "type": "number", "oid": "65", "optional": true, "size": "2"}
    :param server_rst_close_stream: {"description": "Server RST close stream", "format": "counter", "type": "number", "oid": "39", "optional": true, "size": "2"}
    :param data_no_stream: {"description": "Data no stream found", "format": "counter", "type": "number", "oid": "32", "optional": true, "size": "2"}
    :param new_stream_session_del: {"description": "New Stream after Session delete", "format": "counter", "type": "number", "oid": "78", "optional": true, "size": "2"}
    :param ctx_alloc_fail: {"description": "Context alloc fail", "format": "counter", "type": "number", "oid": "37", "optional": true, "size": "2"}
    :param close_stream_session_not_found: {"description": "Close stream session not found", "format": "counter", "type": "number", "oid": "41", "optional": true, "size": "2"}
    :param invalid_version: {"description": "Invalid version", "format": "counter", "type": "number", "oid": "70", "optional": true, "size": "2"}
    :param server_fin: {"description": "Server FIN", "format": "counter", "type": "number", "oid": "20", "optional": true, "size": "2"}
    :param window_frame: {"description": "Window update frame received", "format": "counter", "type": "number", "oid": "29", "optional": true, "size": "2"}
    :param close_session_already_closed: {"description": "Closing closed session", "format": "counter", "type": "number", "oid": "45", "optional": true, "size": "2"}
    :param headers_frame: {"description": "Headers frame received", "format": "counter", "type": "number", "oid": "27", "optional": true, "size": "2"}
    :param server_rst: {"description": "Server RST sent", "format": "counter", "type": "number", "oid": "11", "optional": true, "size": "2"}
    :param header_compress_fail: {"description": "Header compress fail", "format": "counter", "type": "number", "oid": "73", "optional": true, "size": "2"}
    :param tcp_err: {"description": "TCP sock error", "format": "counter", "type": "number", "oid": "14", "optional": true, "size": "2"}
    :param curr_proxy: {"description": "Curr Proxy Conns", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "2"}
    :param name_value_zero_len: {"description": "Name value zero name length", "format": "counter", "type": "number", "oid": "51", "optional": true, "size": "2"}
    :param name_value_keepalive: {"description": "Name value keep alive", "format": "counter", "type": "number", "oid": "54", "optional": true, "size": "2"}
    :param http_close_stream_closed: {"description": "HTTP close stream already closed", "format": "counter", "type": "number", "oid": "80", "optional": true, "size": "2"}
    :param syn_frame: {"description": "SYN stream frame received", "format": "counter", "type": "number", "oid": "25", "optional": true, "size": "2"}
    :param data_frame: {"description": "Data frame received", "format": "counter", "type": "number", "oid": "31", "optional": true, "size": "2"}
    :param total_stream_succ: {"description": "Streams(succ)", "format": "counter", "type": "number", "oid": "9", "optional": true, "size": "2"}
    :param data_no_stream_goaway_close: {"description": "Data no stream and no goaway and close session", "format": "counter", "type": "number", "oid": "34", "optional": true, "size": "2"}
    :param name_value_proxy_conn: {"description": "Name value proxy-connection", "format": "counter", "type": "number", "oid": "55", "optional": true, "size": "2"}
    :param request_header_alloc_fail: {"description": "Request/Header allocation fail", "format": "counter", "type": "number", "oid": "49", "optional": true, "size": "2"}
    :param unknown_control_frame: {"description": "Unknown control frame", "format": "counter", "type": "number", "oid": "67", "optional": true, "size": "2"}
    :param http_data_stream_not_found: {"description": "HTTP data stream not found", "format": "counter", "type": "number", "oid": "75", "optional": true, "size": "2"}
    :param stream_lt_prev: {"description": "Stream id less than previous", "format": "counter", "type": "number", "oid": "60", "optional": true, "size": "2"}
    :param settings_frame: {"description": "Setting frame received", "format": "counter", "type": "number", "oid": "28", "optional": true, "size": "2"}
    :param curr_stream: {"description": "Curr Streams", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "2"}
    :param close_stream_already_closed: {"description": "Closing closed stream", "format": "counter", "type": "number", "oid": "43", "optional": true, "size": "2"}
    :param data_on_closed_stream: {"description": "Data on closed stream", "format": "counter", "type": "number", "oid": "68", "optional": true, "size": "2"}
    :param name_value_trasnfer_encod: {"description": "Name value transfer encoding", "format": "counter", "type": "number", "oid": "56", "optional": true, "size": "2"}
    :param http_conn_alloc_fail: {"description": "HTTP connection allocation fail", "format": "counter", "type": "number", "oid": "48", "optional": true, "size": "2"}
    :param fin_close_session: {"description": "FIN close session", "format": "counter", "type": "number", "oid": "38", "optional": true, "size": "2"}
    :param name_value_no_must_have: {"description": "Name value no must have", "format": "counter", "type": "number", "oid": "57", "optional": true, "size": "2"}
    :param syn_after_goaway: {"description": "SYN after goaway", "format": "counter", "type": "number", "oid": "59", "optional": true, "size": "2"}
    :param syn_reply_frame: {"description": "SYN reply frame received", "format": "counter", "type": "number", "oid": "26", "optional": true, "size": "2"}
    :param name_value_invalid_http_ver: {"description": "Name value invalid http version", "format": "counter", "type": "number", "oid": "52", "optional": true, "size": "2"}
    :param client_rst_nostream: {"description": "Close RST stream not found", "format": "counter", "type": "number", "oid": "64", "optional": true, "size": "2"}
    :param header_after_session_close: {"description": "Header after session close", "format": "counter", "type": "number", "oid": "71", "optional": true, "size": "2"}
    :param stream_not_found: {"description": "STREAM not found", "format": "counter", "type": "number", "oid": "18", "optional": true, "size": "2"}
    :param client_fin: {"description": "Client FIN", "format": "counter", "type": "number", "oid": "19", "optional": true, "size": "2"}
    :param stream_err: {"description": "Stream err", "format": "counter", "type": "number", "oid": "22", "optional": true, "size": "2"}
    :param total_v3_proxy: {"description": "Version 3 Streams", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "2"}
    :param syn_unidir: {"description": "Unidirectional SYN", "format": "counter", "type": "number", "oid": "62", "optional": true, "size": "2"}
    :param http_data_session_close: {"description": "HTTP data session close", "format": "counter", "type": "number", "oid": "74", "optional": true, "size": "2"}
    :param session_err: {"description": "Session err", "format": "counter", "type": "number", "oid": "23", "optional": true, "size": "2"}
    :param close_stream_not_http_proxy: {"description": "Close Stream not http-proxy", "format": "counter", "type": "number", "oid": "76", "optional": true, "size": "2"}
    :param data_no_stream_no_goaway: {"description": "Data no stream and no goaway", "format": "counter", "type": "number", "oid": "33", "optional": true, "size": "2"}
    :param invalid_window_size: {"description": "Invalid window size", "format": "counter", "type": "number", "oid": "66", "optional": true, "size": "2"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.invalid_frame_size = ""
        self.data_cb_no_tuple = ""
        self.compress_ctx_alloc_fail = ""
        self.stream_found = ""
        self.total_proxy = ""
        self.curr_http_proxy = ""
        self.total_v2_proxy = ""
        self.syn_stream_exist_or_even = ""
        self.close_stream_stream_not_found = ""
        self.client_rst = ""
        self.est_cb_no_tuple = ""
        self.stream_alloc_fail = ""
        self.max_concurrent_stream_limit = ""
        self.deflate_ctx = ""
        self.client_goaway = ""
        self.ping_sent = ""
        self.server_goaway = ""
        self.session_needs_requeue = ""
        self.syn_reply_alr_rcvd = ""
        self.total_http_proxy = ""
        self.close_stream_session_close = ""
        self.decompress_fail = ""
        self.ping_frame = ""
        self.inflate_ctx = ""
        self.name_value_total_len_ex = ""
        self.http_err_stream_closed = ""
        self.http_hdr_stream_close = ""
        self.http_data_stream_close = ""
        self.control_frame = ""
        self.session_close = ""
        self.name_value_connection = ""
        self.fin_stream_closed = ""
        self.stream_close = ""
        self.total_stream = ""
        self.window_no_stream = ""
        self.server_rst_close_stream = ""
        self.data_no_stream = ""
        self.new_stream_session_del = ""
        self.ctx_alloc_fail = ""
        self.close_stream_session_not_found = ""
        self.invalid_version = ""
        self.server_fin = ""
        self.window_frame = ""
        self.close_session_already_closed = ""
        self.headers_frame = ""
        self.server_rst = ""
        self.header_compress_fail = ""
        self.tcp_err = ""
        self.curr_proxy = ""
        self.name_value_zero_len = ""
        self.name_value_keepalive = ""
        self.http_close_stream_closed = ""
        self.syn_frame = ""
        self.data_frame = ""
        self.total_stream_succ = ""
        self.data_no_stream_goaway_close = ""
        self.name_value_proxy_conn = ""
        self.request_header_alloc_fail = ""
        self.unknown_control_frame = ""
        self.http_data_stream_not_found = ""
        self.stream_lt_prev = ""
        self.settings_frame = ""
        self.curr_stream = ""
        self.close_stream_already_closed = ""
        self.data_on_closed_stream = ""
        self.name_value_trasnfer_encod = ""
        self.http_conn_alloc_fail = ""
        self.fin_close_session = ""
        self.name_value_no_must_have = ""
        self.syn_after_goaway = ""
        self.syn_reply_frame = ""
        self.name_value_invalid_http_ver = ""
        self.client_rst_nostream = ""
        self.header_after_session_close = ""
        self.stream_not_found = ""
        self.client_fin = ""
        self.stream_err = ""
        self.total_v3_proxy = ""
        self.syn_unidir = ""
        self.http_data_session_close = ""
        self.session_err = ""
        self.close_stream_not_http_proxy = ""
        self.data_no_stream_no_goaway = ""
        self.invalid_window_size = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class SpdyProxy(A10BaseClass):
    
    """Class Description::
    Statistics for the object spdy-proxy.

    Class spdy-proxy supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/spdy-proxy/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "spdy-proxy"
        self.a10_url="/axapi/v3/slb/spdy-proxy/stats"
        self.DeviceProxy = ""
        self.stats = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Oper(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param conn_rate_unit: {"enum": ["100ms", "second"], "type": "string", "format": "enum"}
    :param icmpv6_rate_over_limit_drop: {"type": "number", "format": "number"}
    :param curr_conn_rate: {"type": "number", "format": "number"}
    :param state: {"enum": ["All-Up", "Functional-Up", "Partial-Up", "Down", "Disb", "Unkn"], "type": "string", "format": "enum"}
    :param curr_icmp_rate: {"type": "number", "format": "number"}
    :param icmpv6_lockup_time_left: {"type": "number", "format": "number"}
    :param mac: {"minLength": 11, "maxLength": 17, "type": "string", "format": "mac-address"}
    :param curr_icmpv6_rate: {"type": "number", "format": "number"}
    :param icmp_rate_over_limit_drop: {"type": "number", "format": "number"}
    :param icmp_lockup_time_left: {"type": "number", "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "oper"
        self.DeviceProxy = ""
        self.conn_rate_unit = ""
        self.icmpv6_rate_over_limit_drop = ""
        self.curr_conn_rate = ""
        self.state = ""
        self.curr_icmp_rate = ""
        self.icmpv6_lockup_time_left = ""
        self.mac = ""
        self.curr_icmpv6_rate = ""
        self.icmp_rate_over_limit_drop = ""
        self.icmp_lockup_time_left = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Dns64Virtualserver(A10BaseClass):
    
    """Class Description::
    Operational Status for the object dns64-virtualserver.

    Class dns64-virtualserver supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param port_list: {"minItems": 1, "items": {"type": "port"}, "uniqueItems": true, "array": [{"required": ["port-number", "protocol"], "properties": {"oper": {"type": "object", "properties": {"state": {"enum": ["All-Up", "Functional-Up", "Partial-Up", "Down", "Disb", "Unkn"], "type": "string", "format": "enum"}}}, "protocol": {"enum": ["dns-udp"], "description": "'dns-udp': DNS service over UDP; ", "format": "enum", "type": "string", "oid": "1002", "optional": false}, "port-number": {"description": "Port", "format": "number", "optional": false, "oid": "1001", "maximum": 65534, "minimum": 0, "type": "number"}}}], "type": "array", "$ref": "/axapi/v3/cgnv6/dns64-virtualserver/{name}/port/{port-number}+{protocol}"}
    :param name: {"description": "CGNV6 Virtual Server Name", "format": "string-rlx", "minLength": 1, "oid": "1001", "optional": false, "maxLength": 127, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/dns64-virtualserver/{name}/oper`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "dns64-virtualserver"
        self.a10_url="/axapi/v3/cgnv6/dns64-virtualserver/{name}/oper"
        self.DeviceProxy = ""
        self.oper = {}
        self.port_list = []
        self.name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Waf(A10BaseClass):
    
    """Class Description::
    WAF related commands.

    Class waf supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param template_list: {"minItems": 1, "items": {"type": "template"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"log-succ-reqs": {"default": 0, "optional": true, "type": "number", "description": "Log successful waf requests", "format": "flag"}, "keep-end": {"description": "Number of unmasked characters at the end (default: 0)", "format": "number", "type": "number", "maximum": 65535, "minimum": 0, "optional": true}, "max-cookie-len": {"description": "Max Cookie length allowed in request (default 4096) (Maximum length of cookie allowed (default 4096))", "format": "number", "default": 4096, "optional": true, "maximum": 65535, "minimum": 0, "type": "number"}, "deploy-mode": {"description": "'active': Deploy WAF in active (blocking) mode; 'passive': Deploy WAF in passive (log-only) mode; 'learning': Deploy WAF in learning mode; ", "format": "enum", "default": "active", "type": "string", "enum": ["active", "passive", "learning"], "optional": true}, "xml-format-check": {"default": 0, "optional": true, "type": "number", "description": "Check HTTP body for XML format compliance", "format": "flag"}, "max-string": {"description": "Maximum length of a string in a JSON request body (default 64) (Maximum length of a JSON string (default 64))", "format": "number", "default": 64, "optional": true, "maximum": 4096, "minimum": 0, "type": "number"}, "ccn-mask": {"default": 0, "optional": true, "type": "number", "description": "Mask credit card numbers in response", "format": "flag"}, "waf-blist-file": {"description": "Name of WAF policy list file", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}, "form-set-no-cache": {"default": 0, "optional": true, "type": "number", "description": "Disable caching of form-containing responses", "format": "flag"}, "http-redirect": {"description": "Send HTTP redirect response (302 Found) to specifed URL (URL to redirect to when denying request)", "format": "string-rlx", "minLength": 1, "not-list": ["http-resp-200", "reset-conn", "http-resp-403"], "optional": true, "maxLength": 255, "type": "string"}, "bot-check": {"default": 0, "optional": true, "type": "number", "description": "Check User-Agent for known bots", "format": "flag"}, "max-cookies-len": {"description": "Max Total Cookies length allowed in request (default 4096) (Maximum total length of cookies allowed (default 4096))", "format": "number", "default": 4096, "optional": true, "maximum": 65535, "minimum": 0, "type": "number"}, "url-check": {"default": 0, "optional": true, "type": "number", "description": "Check URL against list of previously learned URLs", "format": "flag"}, "max-parameter-value-len": {"description": "Max HTML parameter value length in an HTTP request (default 4096) (Maximum HTML parameter value in an HTTP request (default 4096))", "format": "number", "default": 4096, "optional": true, "maximum": 102400000, "minimum": 0, "type": "number"}, "max-entities": {"description": "Maximum number of MIME entities allowed in request (default 10)", "format": "number", "default": 10, "optional": true, "maximum": 63, "minimum": 0, "type": "number"}, "hide-resp-codes": {"default": 0, "optional": true, "type": "number", "description": "Hides response codes that are not allowed (default 4xx, 5xx)", "format": "flag"}, "max-depth": {"description": "Maximum recursion depth in a value in a JSON requesnt body (default 16) (Maximum recursion depth in a JSON value (default 16))", "format": "number", "default": 16, "optional": true, "maximum": 4096, "minimum": 0, "type": "number"}, "hide-resp-codes-file": {"description": "Name of WAF policy list file", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}, "max-elem-name-len": {"description": "Maximum length for an element name (default 128)", "format": "number", "default": 128, "optional": true, "maximum": 65535, "minimum": 0, "type": "number"}, "deny-password-autocomplete": {"default": 0, "optional": true, "type": "number", "description": "Check to protect against server-generated form which contain password fields that allow autocomplete", "format": "flag"}, "name": {"description": "WAF Template Name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "http-resp-200": {"description": "Send HTTP response with status code 200 OK", "format": "flag", "default": 0, "optional": true, "not-list": ["http-redirect", "reset-conn", "http-resp-403"], "type": "number"}, "keep-start": {"description": "Number of unmasked characters at the beginning (default: 0)", "format": "number", "type": "number", "maximum": 65535, "minimum": 0, "optional": true}, "redirect-wlist": {"default": 0, "optional": true, "type": "number", "description": "Check Redirect URL against list of previously learned redirects", "format": "flag"}, "max-cookie-value-len": {"description": "Max Cookie Value length allowed in request (default 4096) (Maximum length of cookie value allowed (default 4096))", "format": "number", "default": 4096, "optional": true, "maximum": 65535, "minimum": 0, "type": "number"}, "max-cdata-len": {"description": "Maximum length of an CDATA section of an element (default 65535)", "format": "number", "default": 65535, "optional": true, "maximum": 65535, "minimum": 0, "type": "number"}, "max-hdr-value-len": {"description": "Max header value length allowed in request (default 4096) (Maximum length of header value allowed (default 4096))", "format": "number", "default": 4096, "optional": true, "maximum": 65535, "minimum": 0, "type": "number"}, "secret-encrypted": {"description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED secret string)", "format": "encrypted", "minLength": 1, "optional": true, "maxLength": 255, "type": "encrypted"}, "cookie-name": {"description": "Cookie name (simple string or PCRE pattern)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "max-namespace-uri-len": {"description": "Maximum length of a namespace URI (default 256)", "format": "number", "default": 256, "optional": true, "maximum": 1024, "minimum": 0, "type": "number"}, "resp-url-403": {"description": "Response content to send client when denying request", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 255, "type": "string"}, "csrf-check": {"default": 0, "optional": true, "type": "number", "description": "Tag the form to protect against Cross-site Request Forgery", "format": "flag"}, "referer-domain-list": {"description": "List of referer domains allowed", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 255, "not": "referer-domain-list-only", "type": "string"}, "max-parameters": {"description": "Maximum number of HTML parameters allowed in request (default 64)", "format": "number", "default": 64, "optional": true, "maximum": 1024, "minimum": 0, "type": "number"}, "max-parameter-name-len": {"description": "Max HTML parameter name length in an HTTP request (default 256) (Maximum HTML parameter name length in an HTTP request (default 256))", "format": "number", "default": 256, "optional": true, "maximum": 1024, "minimum": 0, "type": "number"}, "deny-non-masked-passwords": {"default": 0, "optional": true, "type": "number", "description": "Denies forms that have a password field with a textual type, resulting in this field not being masked", "format": "flag"}, "max-hdr-name-len": {"description": "Max header name length allowed in request (default 63) (Maximum length of header name allowed (default 63))", "format": "number", "default": 63, "optional": true, "maximum": 63, "minimum": 0, "type": "number"}, "max-elem-depth": {"description": "Maximum recursion level for element definition (default 256)", "format": "number", "default": 256, "optional": true, "maximum": 4096, "minimum": 0, "type": "number"}, "form-consistency-check": {"default": 0, "optional": true, "type": "number", "description": "Form input consistency check", "format": "flag"}, "max-hdrs": {"description": "Maximum number of headers allowed in request (default 20)", "format": "number", "default": 20, "optional": true, "maximum": 255, "minimum": 0, "type": "number"}, "xml-xss-check": {"default": 0, "optional": true, "type": "number", "description": "Check XML data against XSS policy", "format": "flag"}, "referer-check": {"default": 0, "optional": true, "type": "number", "description": "Check referer to protect against CSRF attacks", "format": "flag"}, "wsdl-resp-val-file": {"description": "Specify name of WSDL file for verifying XML body contents", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "not": "wsdl-file", "type": "string"}, "logging": {"description": "Logging template (Logging Config name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string", "$ref": "/axapi/v3/slb/template/logging"}, "max-namespace": {"description": "Maximum number of namespace declarations (default 16)", "format": "number", "default": 16, "optional": true, "maximum": 256, "minimum": 0, "type": "number"}, "max-entity-exp": {"description": "Maximum number of entity expansions (default 1024)", "format": "number", "default": 1024, "optional": true, "maximum": 1024, "minimum": 0, "type": "number"}, "form-deny-non-post": {"default": 0, "optional": true, "type": "number", "description": "Deny request with forms if the method is not POST", "format": "flag"}, "cookie-encryption-secret": {"description": "Cookie encryption secret", "format": "password", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}, "decode-escaped-chars": {"default": 0, "optional": true, "type": "number", "description": "Decode escaped characters such as \\r \\n \\\" \\xXX \\u00YY in internal url", "format": "flag"}, "json-format-check": {"default": 0, "optional": true, "type": "number", "description": "Check HTTP body for JSON format compliance", "format": "flag"}, "bot-check-policy-file": {"description": "Name of WAF policy list file", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}, "xml-schema-resp-val-file": {"description": "Specify name of XML-Schema file for verifying XML body contents", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "not": "xml-schema-file", "type": "string"}, "allowed-http-methods": {"description": "List of allowed HTTP methods. Default is \"GET POST\". (List of HTTP methods allowed (default \"GET POST\"))", "format": "string-rlx", "default": "GET POST", "minLength": 1, "optional": true, "maxLength": 255, "type": "string"}, "remove-selfref": {"default": 0, "optional": true, "type": "number", "description": "Remove self-references such as /./ and /path/../ from internal url", "format": "flag"}, "max-elem-child": {"description": "Maximum number of children of an XML element (default 1024)", "format": "number", "default": 1024, "optional": true, "maximum": 4096, "minimum": 0, "type": "number"}, "max-entity-exp-depth": {"description": "Maximum nested depth of entity expansion (default 32)", "format": "number", "default": 32, "optional": true, "maximum": 32, "minimum": 0, "type": "number"}, "max-array-value-count": {"description": "Maximum number of values in an array in a JSON request body (default 256) (Maximum number of values in a JSON array (default 256))", "format": "number", "default": 256, "optional": true, "maximum": 4096, "minimum": 0, "type": "number"}, "max-elem": {"description": "Maximum number of XML elements (default 1024)", "format": "number", "default": 1024, "optional": true, "maximum": 8192, "minimum": 0, "type": "number"}, "sqlia-check": {"optional": true, "enum": ["reject", "sanitize"], "type": "string", "description": "'reject': Reject requests with SQLIA patterns; 'sanitize': Remove bad SQL from request; ", "format": "enum"}, "max-object-member-count": {"description": "Maximum number of members in an object in a JSON request body (default 256) (Maximum number of members in a JSON object (default 256))", "format": "number", "default": 256, "optional": true, "maximum": 4096, "minimum": 0, "type": "number"}, "http-resp-403": {"description": "Send HTTP response with status code 403 Forbidden (default)", "format": "flag", "default": 0, "optional": true, "not-list": ["http-redirect", "http-resp-200", "reset-conn"], "type": "number"}, "http-check": {"default": 0, "optional": true, "type": "number", "description": "Check request for HTTP protocol compliance", "format": "flag"}, "max-cookie-name-len": {"description": "Max Cookie Name length allowed in request (default 64) ( Maximum length of cookie name allowed (default 64))", "format": "number", "default": 64, "optional": true, "maximum": 65535, "minimum": 0, "type": "number"}, "remove-comments": {"default": 0, "optional": true, "type": "number", "description": "Remove comments from internal url", "format": "flag"}, "uri-wlist-check": {"default": 0, "optional": true, "type": "number", "description": "specify name of WAF policy list file to whitelist", "format": "flag"}, "form-deny-non-ssl": {"default": 0, "optional": true, "type": "number", "description": "Deny request with forms if the protocol is not SSL", "format": "flag"}, "xss-check": {"optional": true, "enum": ["reject", "sanitize"], "type": "string", "description": "'reject': Reject requests with bad cookies; 'sanitize': Remove bad cookies from request; ", "format": "enum"}, "reset-conn": {"description": "Reset the client connection", "format": "flag", "default": 0, "optional": true, "not-list": ["http-redirect", "http-resp-200", "http-resp-403"], "type": "number"}, "referer-safe-url": {"description": " Safe URL to redirect to if referer is missing", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 255, "type": "string"}, "max-attr-name-len": {"description": "Maximum length of an attribute name (default 128)", "format": "number", "default": 128, "optional": true, "maximum": 2048, "minimum": 0, "type": "number"}, "uri-blist-check": {"default": 0, "optional": true, "type": "number", "description": "specify name of WAF policy list file to blacklist", "format": "flag"}, "max-url-len": {"description": "Max URL length allowed in request (default 1024) (Maximum length of URL allowed (default 1024))", "format": "number", "default": 1024, "optional": true, "maximum": 16127, "minimum": 0, "type": "number"}, "max-hdrs-len": {"description": "Max headers length allowed in request (default 4096) (Maximum length of headers allowed (default 4096))", "format": "number", "default": 4096, "optional": true, "maximum": 65535, "minimum": 0, "type": "number"}, "waf-wlist-file": {"description": "Name of WAF policy list file", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}, "remove-spaces": {"default": 0, "optional": true, "type": "number", "description": "Remove spaces from internal url", "format": "flag"}, "lifetime": {"description": "Session lifetime in minutes (default 10)", "format": "number", "type": "number", "maximum": 1440, "minimum": 1, "optional": true}, "max-attr": {"description": "Maximum number of attributes of an XML element (default 256)", "format": "number", "default": 256, "optional": true, "maximum": 256, "minimum": 0, "type": "number"}, "xss-check-policy-file": {"description": "Name of WAF policy list file", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}, "resp-url-200": {"description": "Response content to send client when denying request", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 255, "type": "string"}, "max-post-size": {"description": "Max content length allowed in POST request (default 20480) (Maximum size allowed content in an HTTP POST request (default 20480))", "format": "number", "default": 20480, "optional": true, "maximum": 2147483647, "minimum": 0, "type": "number"}, "decode-hex-chars": {"default": 0, "optional": true, "type": "number", "description": "Decode hex chars such as \\%xx and \\%u00yy in internal url", "format": "flag"}, "max-line-len": {"description": "Max Line length allowed in request (default 1024) (Maximum length of Request line allowed (default 1024))", "format": "number", "default": 1024, "optional": true, "maximum": 16127, "minimum": 0, "type": "number"}, "max-query-len": {"description": "Max Query length allowed in request (default 1024) (Maximum length of Request query allowed (default 1024))", "format": "number", "default": 1024, "optional": true, "maximum": 16127, "minimum": 0, "type": "number"}, "sqlia-check-policy-file": {"description": "Name of WAF policy list file", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}, "deny-non-ssl-passwords": {"default": 0, "optional": true, "type": "number", "description": "Denies any form that has a password field if the form is not sent over an SSL connection", "format": "flag"}, "max-data-parse": {"description": "Max data parsed for Web Application Firewall (default 65536) (Maximum data parsed for Web Application Firewall (default 65536))", "format": "number", "default": 65536, "optional": true, "maximum": 1048575, "minimum": 0, "type": "number"}, "max-parameter-total-len": {"description": "Max HTML parameter tatal length in an HTTP request (default 4096) (Maximum HTML parameter total length in an HTTP request (default 4096))", "format": "number", "default": 4096, "optional": true, "maximum": 102400000, "minimum": 0, "type": "number"}, "wsdl-file": {"description": "Specify name of WSDL file for verifying XML body contents", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "not": "wsdl-resp-val-file", "type": "string"}, "session-check": {"default": 0, "optional": true, "type": "number", "description": "Enable session checking via session cookie", "format": "flag"}, "disable": {"default": 0, "optional": true, "type": "number", "description": "Disable buffer overflow protection", "format": "flag"}, "filter-resp-hdrs": {"default": 0, "optional": true, "type": "number", "description": "Removes web server's identifying headers", "format": "flag"}, "max-cookies": {"description": "Maximum number of cookies allowed in request (default 20)", "format": "number", "default": 20, "optional": true, "maximum": 63, "minimum": 0, "type": "number"}, "decode-entities": {"default": 0, "optional": true, "type": "number", "description": "Decode entities in internal url", "format": "flag"}, "mask": {"description": "Character to mask the matched pattern (default: X)", "format": "string", "minLength": 1, "optional": true, "maxLength": 1, "type": "string"}, "referer-domain-list-only": {"description": "List of referer domains allowed", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 255, "not": "referer-domain-list", "type": "string"}, "max-attr-value-len": {"description": "Maximum length of an attribute text value (default 128)", "format": "number", "default": 128, "optional": true, "maximum": 4096, "minimum": 0, "type": "number"}, "pcre-mask": {"description": "Mask matched PCRE pattern in response", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "soap-format-check": {"default": 0, "optional": true, "type": "number", "description": "Check XML document for SOAP format compliance", "format": "flag"}, "xml-schema-file": {"description": "Specify name of XML-Schema file for verifying XML body contents", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "not": "xml-schema-resp-val-file", "type": "string"}, "ssn-mask": {"default": 0, "optional": true, "type": "number", "description": "Mask US Social Security numbers in response", "format": "flag"}, "xml-sqlia-check": {"default": 0, "optional": true, "type": "number", "description": "Check XML data against SQLIA policy", "format": "flag"}}}], "type": "array", "$ref": "/axapi/v3/waf/template/{name}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/waf`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "waf"
        self.a10_url="/axapi/v3/waf"
        self.DeviceProxy = ""
        self.policy = {}
        self.wsdl = {}
        self.template_list = []
        self.xml_schema = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)


